@@ -9,7 +9,6 @@ SPDX-License-Identifier: GPL-2.0-or-later
 #include <KLocalizedString>
 #include <kmessagebox.h>
 
-#include "../rkglobals.h"
 #include "../core/robjectlist.h"
 #include "../rbackend/rkrinterface.h"
 #include "../rkward.h"
@@ -23,12 +22,12 @@ RKEditObjectAgent::RKEditObjectAgent (const QStringList &object_names, RCommandC
 	RKEditObjectAgent::object_names = object_names;
 
 	// first issue an empty command to trigger an update of the object list
-	RKGlobals::rInterface ()->issueCommand (new RCommand (QString (), RCommand::EmptyCommand | RCommand::ObjectListUpdate, QString (), this), chain);
+	RInterface::issueCommand (new RCommand (QString (), RCommand::EmptyCommand | RCommand::ObjectListUpdate, QString (), this), chain);
 
 	// now add another empty command to find out, when the update is complete
 	RCommand *command = new RCommand (QString (), RCommand::EmptyCommand, QString (), this);
 	done_command_id = command->id ();
-	RKGlobals::rInterface ()->issueCommand (command, chain);
+	RInterface::issueCommand (command, chain);
 }
 
 RKEditObjectAgent::~RKEditObjectAgent () {
