@@ -11,7 +11,6 @@ SPDX-License-Identifier: GPL-2.0-or-later
 
 #include <qtimer.h>
 
-#include "../rkglobals.h"
 #include "../rbackend/rkrinterface.h"
 #include "../rkward.h"
 #include "../misc/rkprogresscontrol.h"
@@ -32,17 +31,17 @@ RKQuitAgent::RKQuitAgent (QObject *parent) : QObject (parent) {
 	cancel_dialog->addRCommand (command, true);
 	connect (cancel_dialog, &RKProgressControl::cancelled, this, &RKQuitAgent::doQuitNow);
 
-	if (RKGlobals::rInterface ()->backendIsDead ()) {	// nothing to loose
+	if (RInterface::instance()->backendIsDead()) {	// nothing to loose
 		QTimer::singleShot (0, this, SLOT (doQuitNow()));
 		return;
-	} else if (RKGlobals::rInterface ()->backendIsIdle ()) {
+	} else if (RInterface::instance()->backendIsIdle()) {
 		// there should be no problem while quitting. If there is, show the dialog after 300 msec
 		QTimer::singleShot (300, this, SLOT (showWaitDialog()));
 	} else {
 		showWaitDialog ();
 	}
 
-	RKGlobals::rInterface ()->issueCommand (command);
+	RInterface::issueCommand (command);
 }
 
 RKQuitAgent::~RKQuitAgent () {
