@@ -1,19 +1,9 @@
-/***************************************************************************
-                          twintablemember.cpp  -  description
-                             -------------------
-    begin                : Tue Oct 29 2002
-    copyright            : (C) 2002, 2006, 2007, 2009, 2010, 2012 by Thomas Friedrichsmeier
-    email                : thomas.friedrichsmeier@kdemail.net
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+twintablemember.cpp - This file is part of RKWard (https://rkward.kde.org). Created: Tue Oct 29 2002
+SPDX-FileCopyrightText: 2002-2012 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "twintablemember.h"
 
@@ -155,10 +145,10 @@ void TwinTableMember::handleContextMenuRequest (const QPoint& pos) {
 
 	if (sender () == horizontalHeader ()) {
 		int col = horizontalHeader ()->logicalIndexAt (pos);
-		if (col >= 0) emit (contextMenuRequest (-1, col, horizontalHeader ()->mapToGlobal (pos)));
+		if (col >= 0) emit contextMenuRequest(-1, col, horizontalHeader()->mapToGlobal(pos));
 	} else if (sender () == verticalHeader ()) {
 		int row = verticalHeader ()->logicalIndexAt (pos);
-		if (row >= 0) emit (contextMenuRequest (row, -1, verticalHeader ()->mapToGlobal (pos)));
+		if (row >= 0) emit contextMenuRequest(row, -1, verticalHeader()->mapToGlobal(pos));
 	} else {
 		RK_ASSERT (sender () == this);
 
@@ -167,7 +157,7 @@ void TwinTableMember::handleContextMenuRequest (const QPoint& pos) {
 		if ((row < 0) || (col < 0)) {
 			row = col = -2;	// to differentiate from the headers, above
 		}
-		emit (contextMenuRequest (row, col, mapToGlobal (pos)));
+		emit contextMenuRequest(row, col, mapToGlobal(pos));
 	}
 }
 
