@@ -18,10 +18,10 @@ SPDX-License-Identifier: GPL-2.0-or-later
 #include <KLocalizedString>
 #include <KColorScheme>
 
-#include "../rkglobals.h"
 #include "../rbackend/rkrinterface.h"
 #include "../settings/rksettingsmoduler.h"
 #include "../misc/rkcommonfunctions.h"
+#include "../misc/rkstyle.h"
 
 #include "../debug.h"
 
@@ -53,7 +53,6 @@ private:
 	ROutput::ROutputType last_output_type;
 	bool prevent_close;
 	bool is_done;
-	KColorScheme color_scheme;
 };
 
 
@@ -140,12 +139,6 @@ void RKProgressControl::newOutput (const QString &output) {
 	if (dialog) dialog->addOutput (&outputc);
 }
 
-void RKProgressControl::resetOutput () {
-	RK_TRACE (MISC);
-
-	output_log.clear ();
-}
-
 void RKProgressControl::addRCommand (RCommand *command, bool done_when_finished) {
 	RK_TRACE (MISC);
 	RK_ASSERT (command);
@@ -162,7 +155,7 @@ void RKProgressControl::dialogDestroyed () {
 		is_done = true;
 		if (mode & AutoCancelCommands) {
 			for (RCommandList::const_iterator it = outstanding_commands.cbegin (); it != outstanding_commands.cend (); ++it) {
-				RKGlobals::rInterface ()->cancelCommand (*it);
+				RInterface::instance()->cancelCommand(*it);
 			}
 		}
 		emit cancelled();
@@ -228,7 +221,7 @@ QString RKProgressControl::fullCommandOutput() {
 
 #include <kstandardguiitem.h>
 
-RKProgressControlDialog::RKProgressControlDialog(const QString &text, const QString &caption, int mode_flags, bool modal) : QDialog(nullptr), color_scheme(QPalette::Normal) {
+RKProgressControlDialog::RKProgressControlDialog(const QString &text, const QString &caption, int mode_flags, bool modal) : QDialog(nullptr) {
 	RK_TRACE (MISC);
 
 	setAttribute (Qt::WA_DeleteOnClose, true);
@@ -315,9 +308,9 @@ void RKProgressControlDialog::addOutput (const ROutput *output) {
 		output_text->insertPlainText ("\n");
 
 		if (output->type == ROutput::Output) {
-			output_text->setTextColor(color_scheme.foreground(KColorScheme::NormalText).color());
+			output_text->setTextColor(RKStyle::viewScheme()->foreground(KColorScheme::NormalText).color());
 		} else {
-			output_text->setTextColor(color_scheme.foreground(KColorScheme::NegativeText).color());
+			output_text->setTextColor(RKStyle::viewScheme()->foreground(KColorScheme::NegativeText).color());
 			if (!detailsbox->isVisible ()) toggleDetails ();
 			error_indicator->show ();
 		}
@@ -382,3 +375,172 @@ void RKProgressControlDialog::closeEvent (QCloseEvent *e) {
 	}
 }
 
+#include <KMessageWidget>
+#include <KMessageBox>
+#include <KStandardAction>
+
+#include "rkstandardicons.h"
+
+RKInlineProgressControl::RKInlineProgressControl(QWidget *display_area, bool allow_cancel) : QObject(display_area),
+						autoclose(false),
+						allow_cancel(allow_cancel),
+						is_done(false),
+						any_failed(false),
+						display_area(display_area),
+						prevent_close_message(nullptr),
+						close_action(nullptr) {
+	RK_TRACE(MISC);
+
+	display_area->window()->installEventFilter(this);
+
+	wrapper = new QWidget(display_area);
+	wrapper->setAutoFillBackground(true);
+	auto layout = new QVBoxLayout(wrapper);
+	layout->setContentsMargins(0,0,0,0);
+	message_widget = new KMessageWidget();
+	message_widget->setWordWrap(true);
+	message_widget->setCloseButtonVisible(false);  // we want a button, instead, for consistency with cancel
+	if (allow_cancel) {
+		setCloseAction(i18n("Cancel"));
+	}
+	output_display = new QTextEdit();
+	layout->addWidget(message_widget);
+	layout->addWidget(output_display);
+	wrapper->resize(display_area->size());
+}
+
+RKInlineProgressControl::~RKInlineProgressControl() {
+	RK_TRACE(MISC);
+
+	delete wrapper;
+}
+
+void RKInlineProgressControl::setCloseAction(const QString &label) {
+	RK_TRACE(MISC);
+
+	if (!close_action) {
+		close_action = KStandardAction::create(KStandardAction::Close, this, &RKInlineProgressControl::cancelAndClose, this);
+		message_widget->addAction(close_action);
+	}
+	close_action->setText(label);
+}
+
+void RKInlineProgressControl::cancelAndClose() {
+	RK_TRACE(MISC);
+
+	is_done = true;
+	for (int i = 0; i < unfinished_commands.size(); ++i) {
+		RInterface::instance()->cancelCommand(unfinished_commands[i]);
+	}
+	deleteLater();
+}
+
+void RKInlineProgressControl::addRCommand(RCommand *command) {
+	RK_TRACE(MISC);
+	unfinished_commands.append(command);
+	connect(command->notifier(), &RCommandNotifier::commandFinished, this, [this](RCommand *c) {
+		unfinished_commands.removeAll(c);
+		if (c->failed()) {
+			any_failed = true;
+		}
+		if (unfinished_commands.isEmpty()) {
+			done();
+		}
+	});
+	connect(command->notifier(), &RCommandNotifier:: commandOutput, this, [this](RCommand *, const ROutput *o) {
+		addOutput(o->output, o->type != ROutput::Output);
+	});
+}
+
+void RKInlineProgressControl::addOutput(const QString& output, bool is_error_warning) {
+	RK_TRACE(MISC);
+	if (is_error_warning) {
+		output_display->setTextColor(RKStyle::viewScheme()->foreground(KColorScheme::NegativeText).color());
+	} else {
+		output_display->setTextColor(RKStyle::viewScheme()->foreground(KColorScheme::NormalText).color());
+	}
+	output_display->insertPlainText(output);
+}
+
+void RKInlineProgressControl::done() {
+	RK_TRACE(MISC);
+	if (autoclose && !any_failed) {
+		deleteLater();
+	} else {
+		message_widget->setMessageType(any_failed ? KMessageWidget::Error : KMessageWidget::Positive);
+		message_widget->setText(text + ' ' + (any_failed ? i18n("<b>An error occurred</b> (see below for details)") : i18n("<b>Done</b>")));
+		message_widget->setIcon(QIcon::fromTheme(any_failed ? "emblem-error" : "emblem-success"));
+		message_widget->animatedShow(); // to force an update of geometry
+		setCloseAction(i18n("Close"));
+	}
+	is_done = true;
+}
+
+void RKInlineProgressControl::setText(const QString& _text){
+	RK_TRACE(MISC);
+	text = _text;
+	message_widget->setText(text);
+}
+
+void RKInlineProgressControl::show(int delay_ms) {
+	RK_TRACE(MISC);
+	if (delay_ms > 0) {
+		QTimer::singleShot(delay_ms, wrapper, &QWidget::show);
+	} else {
+		wrapper->show();
+	}
+	animation_step = 0;
+	message_widget->setIcon(RKStandardIcons::getIcon(RKStandardIcons::RKWardIcon));
+	auto t = new QTimer(this);
+	t->setInterval(750);
+	connect(t, &QTimer::timeout, this, [this]() {
+		if (is_done) return;
+		animation_step = (animation_step + 1) % 2;
+		if (animation_step) {
+			message_widget->setIcon(QIcon::fromTheme("computer-symbolic"));
+		} else {
+			message_widget->setIcon(RKStandardIcons::getIcon(RKStandardIcons::RKWardIcon));
+		}
+	});
+	t->start();
+}
+
+bool RKInlineProgressControl::eventFilter(QObject *, QEvent *e) {
+	RK_TRACE(MISC);
+	if (e->type() == QEvent::Resize) {
+		QTimer::singleShot(0, this, [this]() {
+			wrapper->resize(display_area->size());
+		});
+		return false;
+	}
+	if ((e->type() == QEvent::Close) && !is_done) {
+		if (allow_cancel) {
+			bool autoclose_save = autoclose;  // must prevent self-destruction while dialog below is active (the operation might complete, while it exec's)
+			autoclose = false;
+
+			bool ignore = (KMessageBox::warningContinueCancel(display_area, i18n("Closing this window will cancel the current operation. Are you sure?"), i18n("Cancel operation"), KGuiItem(i18n("Keep waiting")), KGuiItem(i18n("Cancel && Close"))) == KMessageBox::Continue);
+
+			autoclose = autoclose_save;
+			if (ignore) {
+				e->accept();
+				return true;
+			}
+			cancelAndClose();
+			return false;
+		}
+		// TODO
+		if (!prevent_close_message) {
+			prevent_close_message = new KMessageWidget(i18n("An operation is still running, please wait."), display_area->window());
+		}
+		QSize s = prevent_close_message->sizeHint();
+		prevent_close_message->resize(display_area->window()->width(), s.height());
+		prevent_close_message->setMessageType(KMessageWidget::Error);
+		prevent_close_message->animatedShow();
+		QTimer::singleShot(5000, prevent_close_message, &KMessageWidget::animatedHide);
+		e->ignore();
+		return true;
+	}
+	return false;
+}
+
+
