@@ -23,7 +23,6 @@ SPDX-License-Identifier: GPL-2.0-or-later
 #include "../windows/rkworkplace.h"
 #include "../rbackend/rcommand.h"
 #include "../rbackend/rkrinterface.h"
-#include "../rkglobals.h"
 #include "rkstandardicons.h"
 
 #include "../debug.h"
@@ -196,9 +195,9 @@ void RKPreviewManager::setCommand (RCommand* command) {
 	// Send an empty dummy command first. This is to sync up with any commands that should have been run _before_ the preview (e.g. to set up the preview area, so that status labels can be shown)
 	RCommand *dummy = new RCommand (QString (), RCommand::App | RCommand::Sync | RCommand::EmptyCommand);
 	connect(dummy->notifier(), &RCommandNotifier::commandFinished, this, [this]() { setStatusMessage(shortStatusLabel()); });
-	RKGlobals::rInterface ()->issueCommand (dummy);
+	RInterface::issueCommand (dummy);
 
-	RKGlobals::rInterface ()->issueCommand (command);
+	RInterface::issueCommand (command);
 	setStatusMessage (shortStatusLabel ());
 }
 
