@@ -84,6 +84,7 @@ the specialized properties (e.g. RKComponentPropertyInt::intValue () always retu
 #include "rkcomponentproperties.h"
 
 #include "../misc/rkcommonfunctions.h"
+#include "../misc/rkcompatibility.h"
 
 #include <KLocalizedString>
 
@@ -778,7 +779,7 @@ void RKComponentPropertyDouble::internalSetValue (const QString &new_value) {
 
 ///////////////////////////////////////////////// RObjects ////////////////////////////////////////////////////////
 
-#include "../rkglobals.h"
+
 #include "../core/robjectlist.h"
 #include "../core/rkvariable.h"
 #include "../core/rcontainerobject.h"
@@ -1004,13 +1005,13 @@ bool RKComponentPropertyRObjects::setValueList (const QStringList& values) {
 bool RKComponentPropertyRObjects::setValue (const QString &value) {
 	RK_TRACE (PLUGIN);
 
-	return setValueList (value.split (sep, QString::SkipEmptyParts));
+	return setValueList (value.split (sep, RKCompatibility::SkipEmptyParts()));
 }
 
 bool RKComponentPropertyRObjects::isStringValid (const QString &value) {
 	RK_TRACE (PLUGIN);
 
-	QStringList slist = value.split (sep, QString::SkipEmptyParts);
+	QStringList slist = value.split (sep, RKCompatibility::SkipEmptyParts());
 
 	for (QStringList::const_iterator it = slist.cbegin (); it != slist.cend (); ++it) {
 		RObject *obj = RObjectList::getObjectList ()->findObject (*it);
