@@ -23,14 +23,16 @@ SPDX-License-Identifier: GPL-2.0-or-later
 
 #include "rkcomponentmap.h"
 #include "../misc/rkcommonfunctions.h"
+#include "../misc/rkcompatibility.h"
 #include "../misc/rkstandardicons.h"
 #include "../misc/rkxmlguipreviewarea.h"
+#include "../misc/rkstyle.h"
 #include "../windows/rkworkplace.h"
 #include "../windows/rkcommandeditorwindow.h"
 #include "../rbackend/rkrinterface.h"
 #include "../rkward.h"
 #include "../settings/rksettingsmoduleplugins.h"
-#include "../rkglobals.h"
+
 #include "../debug.h"
 
 class RKExtensionSplitter : public QSplitter {
@@ -74,7 +76,7 @@ public:
 		setSizes (sizes);
 
 		if (QSplitter::window ()->isVisible ()) {
-			QRect boundary = RKCommonFunctions::availableGeometry(this);
+			QRect boundary = RKCompatibility::availableGeometry(this);
 			int new_width = window->width ();
 			int new_height = window->height ();
 			int new_x = window->x ();
@@ -178,7 +180,7 @@ void RKStandardComponentGUI::createDialog (bool switchable) {
 	QVBoxLayout* vbox = new QVBoxLayout ();
 	hbox->addLayout (vbox);
 	vbox->setContentsMargins (0, 0, 0, 0);
-	vbox->setSpacing (RKGlobals::spacingHint ());
+	vbox->setSpacing (RKStyle::spacingHint ());
 	ok_button = new QPushButton (i18n ("Submit"), central_widget);
 	connect (ok_button, &QPushButton::clicked, this, &RKStandardComponentGUI::ok);
 	vbox->addWidget (ok_button);
@@ -309,7 +311,7 @@ void RKStandardComponentGUI::ok () {
 	command.append (code_property->calculate ());
 	command.append (code_property->printout ());
 	command.append ("})\n");
-	RKGlobals::rInterface ()->issueCommand (new RCommand (command, RCommand::Plugin | RCommand::CCOutput | RCommand::ObjectListUpdate), component->commandChain ());
+	RInterface::issueCommand (new RCommand (command, RCommand::Plugin | RCommand::CCOutput | RCommand::ObjectListUpdate), component->commandChain ());
 
 	// re-run link
 	// This should be run in a separate command, in case the above command bails out with an error. Even in that case, the re-run link should be printed.
@@ -323,7 +325,7 @@ void RKStandardComponentGUI::ok () {
 	}
 	// separator line
 	command.append (".rk.make.hr()\n");
-	RKGlobals::rInterface ()->issueCommand (new RCommand (command, RCommand::Plugin | RCommand::ObjectListUpdate | RCommand::Silent), component->commandChain ());
+	RInterface::issueCommand (new RCommand (command, RCommand::Plugin | RCommand::ObjectListUpdate | RCommand::Silent), component->commandChain ());
 
 	if (auto_close_box->isChecked ()) cancel ();
 }
