@@ -4,10 +4,17 @@ var constMad;
 
 function calculate () {
 	var vars = getList ("x");
+	var groups = getList ("groups");
 	constMad = getValue ("constMad");
 	mad_type = getValue ("mad_type");
 
 	echo ('vars <- rk.list (' + vars.join (", ") + ')\n');
+	if (groups.length) {
+		comment("Split each input variable by grouping factor(s)");
+		echo('vars <- lapply (vars, function (x) split(x, list (' + groups.join(', ') + ')))\n');
+		comment("Convert nested list into flat list");
+		echo('vars <- unlist (vars, recursive=FALSE)\n');
+	}
 	echo ('results <- data.frame (' + i18n ("Object") + '=I(names (vars)))\n');
 	echo ('for (i in 1:length (vars)) {\n');
 	echo ('	var <- vars[[i]]\n');
@@ -61,10 +68,12 @@ function calculate () {
 	echo ('}\n');
 }
 
-function printout () {
-	new Header (i18n ("Descriptive statistics")).addFromUI ("trim").print ();
-	if (getValue ("mad")) {
-		new Header (i18n ("Median Absolute Deviation"), 3).addFromUI ("constMad").addFromUI ("mad_type").print ();
+function printout (is_preview) {
+	if (!is_preview) {
+		new Header (i18n ("Descriptive statistics")).addFromUI ("trim").print ();
+		if (getValue ("mad")) {
+			new Header (i18n ("Median Absolute Deviation"), 3).addFromUI ("constMad").addFromUI ("mad_type").print ();
+		}
 	}
 	echo ('rk.results (results)\n');
 	if (getValue ("save_to_file")) echo ('write.csv(file="' + getValue ("file") + '", results)\n');
