@@ -32,7 +32,6 @@ void* RKRBackend::default_global_context = 0;
 #include "../core/robject.h"
 #include "../version.h"
 #include "../debug.h"
-
 #include "rkrsupport.h"
 #include "rkstructuregetter.h"
 #include "rksignalsupport.h"
@@ -130,6 +129,7 @@ void RKRBackend::scheduleInterrupt () {
 
 void RKRBackend::interruptCommand (int command_id) {
 	RK_TRACE (RBACKEND);
+	RK_DEBUG(RBACKEND, DL_DEBUG, "Received interrupt request for command id %d", command_id);
 	QMutexLocker lock (&all_current_commands_mutex);
 
 	if (all_current_commands.isEmpty ()) return;
@@ -820,7 +820,11 @@ void RKRBackend::setupCallbacks () {
 	RK_R_Params.home = getRUser ();
 	RK_R_Params.CharacterMode = RGui;
 	RK_R_Params.ShowMessage = RShowMessage;
+#if R_VERSION < R_Version(4, 2, 0)
 	RK_R_Params.ReadConsole = RReadConsoleWin;
+#else
+	RK_R_Params.ReadConsole = RReadConsole;
+#endif
 	RK_R_Params.WriteConsoleEx = RWriteConsoleEx;
 	RK_R_Params.WriteConsole = 0;
 	RK_R_Params.CallBack = RKREventLoop::winRKEventHandlerWrapper;
@@ -1040,7 +1044,7 @@ SEXP doCopyNoEval (SEXP fromname, SEXP fromenv, SEXP toname, SEXP toenv) {
 	return (R_NilValue);
 }
 
-SEXP doCaptureOutput (SEXP mode, SEXP capture_messages, SEXP capture_output, SEXP suppress_messages, SEXP suppress_output) {
+SEXP doCaptureOutput (SEXP mode, SEXP capture_messages, SEXP capture_output, SEXP suppress_messages, SEXP suppress_output, SEXP allow_nesting) {
 	RK_TRACE (RBACKEND);
 
 	if (RKRSupport::SEXPToInt (mode) == 1) {
@@ -1049,6 +1053,7 @@ SEXP doCaptureOutput (SEXP mode, SEXP capture_messages, SEXP capture_output, SEX
 		if (RKRSupport::SEXPToInt (capture_output)) cm |= RKROutputBuffer::RecordOutput;
 		if (RKRSupport::SEXPToInt (suppress_messages)) cm |= RKROutputBuffer::SuppressMessages;
 		if (RKRSupport::SEXPToInt (suppress_output)) cm |= RKROutputBuffer::SuppressOutput;
+		if (!RKRSupport::SEXPToInt (allow_nesting)) cm |= RKROutputBuffer::NoNesting;
 		RKRBackend::this_pointer->pushOutputCapture (cm);
 		return (R_NilValue);
 	} else {
@@ -1145,7 +1150,7 @@ bool RKRBackend::startR () {
 		{ "rk.show.files", (DL_FUNC) (void*) &doShowFiles, 5 },
 		{ "rk.dialog", (DL_FUNC) (void*) &doDialog, 7 },
 		{ "rk.update.locale", (DL_FUNC) (void*) &doUpdateLocale, 0 },
-		{ "rk.capture.output", (DL_FUNC) (void*) &doCaptureOutput, 5 },
+		{ "rk.capture.output", (DL_FUNC) (void*) &doCaptureOutput, 6 },
 		{ "rk.graphics.device", (DL_FUNC) (void*) &RKStartGraphicsDevice, 7},
 		{ "rk.graphics.device.resize", (DL_FUNC) (void*) &RKD_AdjustSize, 2},
 		{ 0, 0, 0 }
@@ -1711,11 +1716,11 @@ void RKRBackend::initialize (const QString &locale_dir) {
 	QString error_messages;
 	if (lib_load_fail) {
 		error_messages.append (i18n ("</p>\t- The 'rkward' R-library either could not be loaded at all, or not in the correct version. This may lead to all sorts of errors, from single missing features to complete failure to function. The most likely cause is that the last installation did not place all files in the correct place. However, in some cases, left-overs from a previous installation that was not cleanly removed may be the cause.</p>\
-		<p><b>You should quit RKWard, now, and fix your installation</b>. For help with that, see <a href=\"http://rkward.kde.org/compiling\">http://rkward.kde.org/compiling</a>.</p>\n"));
+		<p><b>You should quit RKWard, now, and fix your installation</b>. For help with that, see <a href=\"https://rkward.kde.org/compiling\">https://rkward.kde.org/compiling</a>.</p>\n"));
 	}
 	if (sink_fail) {
 		error_messages.append (i18n ("<p>\t-There was a problem setting up the communication with R. Most likely this indicates a broken installation.</p>\
-		<p><b>You should quit RKWard, now, and fix your installation</b>. For help with that, see <a href=\"http://rkward.kde.org/compiling\">http://rkward.kde.org/compiling</a>.</p></p>\n"));
+		<p><b>You should quit RKWard, now, and fix your installation</b>. For help with that, see <a href=\"https://rkward.kde.org/compiling\">https://rkward.kde.org/compiling</a>.</p></p>\n"));
 	}
 
 	RBackendRequest req (true, RBackendRequest::Started);
