@@ -1,19 +1,9 @@
-/***************************************************************************
-                          rkrbackend  -  description
-                             -------------------
-    begin                : Sun Jul 25 2004
-    copyright            : (C) 2004 - 2020 by Thomas Friedrichsmeier
-    email                : thomas.friedrichsmeier@kdemail.net
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+rkrbackend - This file is part of the RKWard project. Created: Sun Jul 25 2004
+SPDX-FileCopyrightText: 2004-2020 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef RKRBACKEND_H
 #define RKRBACKEND_H
@@ -104,13 +94,13 @@ public:
 @returns a pointer to the RCommandProxy-instance that was created and used, internally. You can query this pointer for status and data. Be sure to delete it, when done. */
 	RCommandProxy *runDirectCommand (const QString &command, RCommand::CommandTypes datatype); 
 
-	void handleRequest (RBackendRequest *request) { handleRequest (request, true); };
+	void handleRequest(RBackendRequest *request) { handleRequest (request, true); };
 /** A relic of history. In contrast to handlePlainGenericRequest(), these requests support running sub-commands. However, the remaining requests which are currently handled this way
 should probably be converted to dedicated RKRBackendRequest's in the future. See also handlePlainGenericRequest(). */
-	void handleHistoricalSubstackRequest (const QStringList &list);
-/** Sends a request to the frontend and returns the result (an empty QStringList in case of asynchronous requests). Note that this function has considerable overlap with
+	GenericRRequestResult handleRequestWithSubcommands(const QStringList &list);
+/** Sends a request to the frontend and returns the result (empty in case of asynchronous requests). Note that this function has considerable overlap with
 handleHistoricalSubstackRequest(). Exactly which requests get handled by which function is somewhat arbitrary, ATM. However, request that do not need sub-commands to be run, should generally be converted to use handlePlainGenericRequest(). (And probably all historicalSubstackRequests should be replaced!) */
-	QStringList handlePlainGenericRequest (const QStringList &parameters, bool synchronous);
+	GenericRRequestResult handlePlainGenericRequest(const QStringList &parameters, bool synchronous);
 	RCommandProxy* fetchNextCommand ();
 
 /** The command currently being executed. */
@@ -202,10 +192,13 @@ handleHistoricalSubstackRequest(). Exactly which requests get handled by which f
 	RCommandProxy *pending_priority_command;
 	QMutex priority_command_mutex;
 	int r_version;
+
+	bool graphicsEngineMismatchMessage(int compiled_version, int runtime_version);
 private:
 	void clearPendingInterrupt ();
 protected:
-	RCommandProxy* handleRequest (RBackendRequest *request, bool mayHandleSubstack);
+	RCommandProxy* handleRequest(RBackendRequest *request, bool mayHandleSubstack);
+	RCommandProxy* handleRequest2(RBackendRequest *request, bool mayHandleSubstack);
 private:
 	int stdout_stderr_fd;
 /** set up R standard callbacks */
