@@ -34,20 +34,21 @@ class RBackendRequest;
 class RInterface : public QObject, public RCommandReceiver {
 	Q_OBJECT
 public:
-/** constructor */
-	RInterface();
+	static void create();
 /** destructor */
 	~RInterface();
 
+	static RInterface* instance() { return _instance; };
+
 /** issues the given command in the given chain */
-	void issueCommand (RCommand *command, RCommandChain *chain=0);
-/** convenience function to create a new command and issue it. See documentation on RCommand::RCommand () and RInterface::issueCommand () */
-	void issueCommand (const QString &command, int type = 0, const QString &rk_equiv = QString (), RCommandReceiver *receiver=0, int flags=0, RCommandChain *chain=0);
+	static void issueCommand(RCommand *command, RCommandChain *chain=0);
+/** convenience function to create a new command and issue it. See documentation on RCommand::RCommand() and RInterface::issueCommand() */
+	static void issueCommand(const QString &command, int type = 0, const QString &rk_equiv = QString(), RCommandReceiver *receiver=0, int flags=0, RCommandChain *chain=0);
 
 /** opens a new command chain. Returns a pointer to the new chain. If you specify a parent, the new chain will be a sub-chain of that chain. */
-	RCommandChain *startChain (RCommandChain *parent=0);
+	static RCommandChain *startChain(RCommandChain *parent=0);
 /** closes the command chain. The chain (and even its parent, if it is already closed) may be deleted right afterwards! */
-	void closeChain (RCommandChain *chain);
+	static void closeChain(RCommandChain *chain);
 
 /** Ensures that the given command will not be executed, or, if it is already running, interrupts it. Note that commands marked RCommand::Sync can
 not be interrupted. */
@@ -133,6 +134,10 @@ friend class RCommand;
 protected:
 	void handleRequest (RBackendRequest *request);
 	void rCommandDone (RCommand *command) override;
+	static RInterface *_instance;
+	void _issueCommand(RCommand *command, RCommandChain *chain=0);
+/** constructor */
+	RInterface();
 signals:
 	void backendWorkdirChanged();
 /** Note: status is actually RInterface::RStatus */
@@ -156,10 +161,10 @@ happens (whether the command runs successfully, or what the output is). For this
 code:
 
 \code
-#include "rkglobals.h"
+
 #include "rbackend/rinterface.h"
 
-RKGlobals::rInterface ()->issueCommand ("print (\"hello world!\")", RCommand::User);
+RInterface::issueCommand ("print (\"hello world!\")", RCommand::User);
 \endcode
 
 You will note, that actually there are two RInterface::issueCommand functions, this one is obviously the one taking a QString and several further
@@ -181,7 +186,7 @@ want to handle the results of RCommands from RCommandReceiver. When finished, th
 The corresponding code would look something like this:
 
 \code
-#include "rkglobals.h"
+
 #include "rbackend/rinterface.h"
 #include "rbackend/rcommandreceiver.h"
 
@@ -199,7 +204,7 @@ private:
 
 
 void MyReceiver::someFunction () {
-	RKGlobals::rInterface ()->issueCommand ("print (1+1)", RCommand::App, QString (), this);
+	RInterface::issueCommand ("print (1+1)", RCommand::App, QString (), this);
 }
 
 void MyReceiver::rCommandDone (RCommand *command) {
@@ -232,7 +237,7 @@ To illustrate the option of using "FLAGS", here is a reduced example of how RKVa
 void RKVariable::updateFromR () {
 	//...
 	RCommand *command = new RCommand ("length (" + getFullName () + ")", RCommand::App | RCommand::Sync | RCommand::GetIntVector, QString (), this, UPDATE_DIM_COMMAND);
-	RKGlobals::rInterface ()->issueCommand (command, RKGlobals::rObjectList()->getUpdateCommandChain ());
+	RInterface::issueCommand (command, RKGlobals::rObjectList()->getUpdateCommandChain ());
 }
 
 void RKVariable::rCommandDone (RCommand *command) {
@@ -240,7 +245,7 @@ void RKVariable::rCommandDone (RCommand *command) {
 	if (command->getFlags () == UPDATE_DIM_COMMAND) {
 		// ...
 		RCommand *ncommand = new RCommand ("class (" + getFullName () + ")", RCommand::App | RCommand::Sync | RCommand::GetStringVector, QString (), this, UPDATE_CLASS_COMMAND);
-		RKGlobals::rInterface ()->issueCommand (ncommand, RKGlobals::rObjectList()->getUpdateCommandChain ());
+		RInterface::issueCommand (ncommand, RKGlobals::rObjectList()->getUpdateCommandChain ());
 	} else if (command->getFlags () == UPDATE_CLASS_COMMAND) {
 		//...
 	}
@@ -306,17 +311,17 @@ To cope with this, it is sometimes desirable to keep closer control over the ord
 The way to do this is to use RCommandChain. Basically, when you want commands to be executed in a sequence being sure that no other commands intervene, you do this:
 
 \code
-	RCommandChain *chain = RKGlobals::rInterface ()->startChain ();
+	RCommandChain *chain = RInterface::startChain ();
 
 	// create first command
-	RKGlobals::rInterface ()->issueCommand (first_command, chain);
+	RInterface::issueCommand (first_command, chain);
 
 	// wait for command to return, potentially allows further calls to RInterface::issueCommand () from other places in the code
 
 	// create second command
-	RKGlobals::rInterface ()->issueCommand (second_command, chain);
+	RInterface::issueCommand (second_command, chain);
 
-	RKGlobals::rInterface ()->closeChain (chain);
+	RInterface::closeChain (chain);
 \endcode
 
 Now the point is that you place both of your commands in a dedicated "chain", telling RKWard that those two commands will have to be run in direct succession. If between the first and the second command, another section of the code issues a different command, this command will never be run until all commands in the chain have been run and the chain has been marked as closed.
@@ -324,12 +329,12 @@ Now the point is that you place both of your commands in a dedicated "chain", te
 To illustrate, consider this series of events:
 
 \code
-1) RCommandChain *chain = RKGlobals::rInterface ()->startChain ();
-2) RKGlobals::rInterface ()->issueCommand (first_command, chain);
-3) RKGlobals::rInterface ()->issueCommand (some_command);
-4) RKGlobals::rInterface ()->issueCommand (second_command, chain);
-5) RKGlobals::rInterface ()->issueCommand (some_command2);
-6) RKGlobals::rInterface ()->closeChain (chain);
+1) RCommandChain *chain = RInterface::startChain ();
+2) RInterface::issueCommand (first_command, chain);
+3) RInterface::issueCommand (some_command);
+4) RInterface::issueCommand (second_command, chain);
+5) RInterface::issueCommand (some_command2);
+6) RInterface::closeChain (chain);
 \endcode
 
 Now let's assume for a second, the R backend has been busy doing other stuff and has not executed any of the commands so far, then the execution stack will now look like this:
@@ -345,7 +350,7 @@ Now let's assume for a second, the R backend has been busy doing other stuff and
 So the order of execution will be guaranteed to be first_command, second_command, some_command, some_command2, although they were issued ina different order. You can also open sub chains, using
 
 \code
-RCommandChain *sub_chain = RKGlobals::rInterface ()->startChain (parent_chain);
+RCommandChain *sub_chain = RInterface::startChain (parent_chain);
 \endcode
 
 Remember to close chains when you placed all the commands you needed to. If you don't close the chain, RKWard will continue to wait for new commands in that chain, and never proceed with commands outside of the chain.
@@ -364,7 +369,7 @@ This is typically used in plugins: When you specify this modifier, the plain tex
 These are special modifiers helpful when transferring data from R to RKWard (used primarily in the editor classes and in conjunction with RCommand::Sync): They tell the backend to try to fetch the result as an array of int, char*, or double, respectively. For instance, if you know object "myobject" is an integer vector, you may get the data using
 
 \code
-RKGlobals::rInterface ()->issueCommand ("myobject", RCommand::Sync | RCommand::GetIntVector, QString (), this);
+RInterface::issueCommand ("myobject", RCommand::Sync | RCommand::GetIntVector, QString (), this);
 \endcode
 
 Assuming the data can in fact be converted to a vector of integers, you can then access the data using these members in RCommand:
