@@ -24,10 +24,10 @@ SPDX-License-Identifier: GPL-2.0-or-later
 #include "../debug.h"
 
 RKSessionVars* RKSessionVars::_instance = 0;
-quint32 RKSessionVars::rkward_version = 0;
-QString RKSessionVars::rkward_version_suffix;
-quint32 RKSessionVars::r_version = 0;
+RKParsedVersion RKSessionVars::rkward_version(RKWARD_VERSION);
+RKParsedVersion RKSessionVars::r_version;
 QString RKSessionVars::r_version_string;
+QString RKSessionVars::r_binary;
 
 RKSessionVars::RKSessionVars (RInterface *parent) : QObject (parent) {
 	RK_TRACE (RBACKEND);
@@ -54,7 +54,7 @@ void RKSessionVars::setRVersion (const QString& version_string) {
 		RK_DEBUG (RBACKEND, DL_WARNING, "R version has changed during runtime, from %s to %s", qPrintable (r_version_string), qPrintable (version_string));
 	}
 	r_version_string = version_string;
-	r_version = parseVersionString (version_string, 0);
+	r_version = RKParsedVersion(version_string);
 }
 
 QString RKSessionVars::RVersion(bool abbridged) {
@@ -62,56 +62,18 @@ QString RKSessionVars::RVersion(bool abbridged) {
 	return r_version_string.section ('.', 0, 1);
 }
 
-quint32 RKSessionVars::parseVersionString (const QString &version, QString *suffix) {
-	quint32 ret = 0;
-	int pos = -1;
-	int opos = 0;
-	for (int i = 3; i >= 0; --i) {
-		while (true) {
-			++pos;
-			if (!(pos < version.size () && version[pos].isDigit ())) {
-				int val = version.midRef(opos, pos - opos).toInt();
-				if ((val < 0) || (val > 255) || (pos == opos)) {
-					RK_DEBUG (MISC, DL_ERROR, "Invalid version specification '%s'", qPrintable (version));
-					if (val > 255) val = 255;
-					else val = 0;
-				}
-				ret += val << (8 * i);
-				if ((pos < version.size ()) && (version[pos] == '.')) {
-					opos = pos + 1;
-					break;
-				}
-				opos = pos;
-				i = -1;
-				break;
-			}
-		}
-	}
-	if (opos <= (version.size () - 1)) {
-		if (suffix) *suffix = version.mid (opos);
-		else RK_DEBUG (MISC, DL_WARNING, "Non numeric portion ('%s') of version specification '%s' will be ignored.", qPrintable (version.mid (opos)), qPrintable (version));
-	}
-
-	return ret;
-}
-
 int RKSessionVars::compareRKWardVersion (const QString& version) {
-	if (!rkward_version) {
-		rkward_version = parseVersionString (RKWARD_VERSION, &rkward_version_suffix);
-	}
-
-	QString suffix;
-	quint32 ver = parseVersionString (version, &suffix);
-	if (ver < rkward_version) return -1;
+	auto ver = RKParsedVersion(version);
+	if (rkward_version > ver) return -1;
 	if (ver > rkward_version) return 1;
-	return (suffix.compare (rkward_version_suffix));
+	return 0;
 }
 
 int RKSessionVars::compareRVersion (const QString& version) {
 	if (r_version_string.isEmpty()) return 0;
 
-	quint32 ver = parseVersionString (version, 0);
-	if (ver < r_version) return -1;
+	auto ver = RKParsedVersion(version);
+	if (r_version > ver) return -1;
 	if (ver > r_version) return 1;
 	return 0;
 }
