@@ -1,19 +1,9 @@
-/***************************************************************************
-                          rktransmitter  -  description
-                             -------------------
-    begin                : Thu Nov 18 2010
-    copyright            : (C) 2010, 2013 by Thomas Friedrichsmeier
-    email                : thomas.friedrichsmeier@kdemail.net
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+rktransmitter - This file is part of RKWard (https://rkward.kde.org). Created: Thu Nov 18 2010
+SPDX-FileCopyrightText: 2010-2013 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "rktransmitter.h"
 
@@ -40,6 +30,12 @@ void RKRBackendSerializer::serialize (const RBackendRequest &request, QDataStrea
 		stream << false;
 	}
 	stream << request.params;
+	if (request.subcommandrequest) {
+		stream << true;
+		serialize(*(request.subcommandrequest), stream);
+	} else {
+		stream << false;
+	}
 }
 
 RBackendRequest *RKRBackendSerializer::unserialize (QDataStream &stream) {
@@ -63,6 +59,8 @@ RBackendRequest *RKRBackendSerializer::unserialize (QDataStream &stream) {
 	stream >> dummyb;
 	if (dummyb) request->output = unserializeOutput (stream);
 	stream >> request->params;
+	stream >> dummyb;
+	if (dummyb) request->subcommandrequest = unserialize(stream);
 
 	return request;
 }
