@@ -41,7 +41,7 @@ SPDX-License-Identifier: GPL-2.0-or-later
 #include <KJobWidgets>
 #include <KJobUiDelegate>
 
-#include "rkglobals.h"
+
 #include "rkward.h"
 #include "windows/rkhelpsearchwindow.h"
 #include "windows/rkcodecompletion.h"
@@ -49,8 +49,9 @@ SPDX-License-Identifier: GPL-2.0-or-later
 #include "rbackend/rcommand.h"
 #include "settings/rksettings.h"
 #include "settings/rksettingsmoduleconsole.h"
-#include "settings/rksettingsmodulegeneral.h"
+#include "settings/rkrecenturls.h"
 #include "misc/rkcommonfunctions.h"
+#include "misc/rkcompatibility.h"
 #include "misc/rkstandardicons.h"
 #include "misc/rkstandardactions.h"
 #include "core/robjectlist.h"
@@ -487,7 +488,7 @@ void RKConsole::submitCommand () {
 	doc->insertLine (doc->lines (), QString ());
 	if (!command.isEmpty ()) {
 		current_command = new RCommand (command, RCommand::User | RCommand::Console, QString (), this);
-		RKGlobals::rInterface ()->issueCommand (current_command);
+		RInterface::issueCommand (current_command);
 		interrupt_command_action->setEnabled (true);
 	} else {
 		showPrompt ();
@@ -690,9 +691,8 @@ void RKConsole::userLoadHistory (const QUrl &_url) {
 
 	QUrl url = _url;
 	if (url.isEmpty ()) {
-		url = QFileDialog::getOpenFileUrl (this, i18n ("Select command history file to load"), RKSettingsModuleGeneral::lastUsedUrlFor ("rscripts"), i18n ("R history files [*.Rhistory](*.Rhistory);;All files [*](*)"));
+		url = QFileDialog::getOpenFileUrl (this, i18n ("Select command history file to load"), RKRecentUrls::mostRecentUrl(RKRecentUrls::scriptsId()).adjusted(QUrl::RemoveFilename), i18n ("R history files [*.Rhistory](*.Rhistory);;All files [*](*)"));
 		if (url.isEmpty ()) return;
-		RKSettingsModuleGeneral::updateLastUsedUrl ("rscripts", url.adjusted (QUrl::RemoveFilename));
 	}
 
 	QTemporaryFile *tmpfile = 0;
@@ -713,7 +713,7 @@ void RKConsole::userLoadHistory (const QUrl &_url) {
 
 	QFile file (filename);
 	if (!file.open (QIODevice::Text | QIODevice::ReadOnly)) return;
-	setCommandHistory (QString (file.readAll ()).split ('\n', QString::SkipEmptyParts), false);
+	setCommandHistory (QString (file.readAll ()).split ('\n', RKCompatibility::SkipEmptyParts()), false);
 	file.close ();
 
 	delete (tmpfile);
@@ -801,7 +801,7 @@ void RKConsole::resetConsole () {
 
 	input_buffer.clear ();
 	if (current_command) {
-		RKGlobals::rInterface ()->cancelCommand (current_command);
+		RInterface::instance()->cancelCommand(current_command);
 	} else {
 		prefix = nprefix;
 		incomplete_command.clear ();
@@ -880,7 +880,7 @@ void RKConsole::pipeUserCommand (const QString &command) {
 		RKConsole::mainConsole ()->pipeCommandThroughConsoleLocal (command);
 	} else {
 		RCommand *cmd = new RCommand (command, RCommand::User);
-		RKGlobals::rInterface ()->issueCommand (cmd);
+		RInterface::issueCommand (cmd);
 	}
 }
 
@@ -897,7 +897,7 @@ void RKConsole::pipeCommandThroughConsoleLocal (const QString &command_string) {
 		}
 	}
 	if (RKSettingsModuleConsole::addPipedCommandsToHistory() != RKSettingsModuleConsole::DontAdd) {
-		QStringList lines = command_string.split ('\n', QString::SkipEmptyParts);
+		QStringList lines = command_string.split ('\n', RKCompatibility::SkipEmptyParts());
 		if ((RKSettingsModuleConsole::addPipedCommandsToHistory() == RKSettingsModuleConsole::AlwaysAdd) || (lines.count () == 1)) {
 			for (int i = 0; i < lines.count (); ++i) {
 				commands_history.append (lines[i]);
