@@ -47,16 +47,17 @@ SPDX-License-Identifier: GPL-2.0-or-later
 #include "settings/rksettingsmoduleoutput.h"
 #include "settings/rksettingsmodulecommandeditor.h"
 #include "settings/rksettingsmodulekateplugins.h"
+#include "settings/rkrecenturls.h"
 #include "rbackend/rkrinterface.h"
 #include "core/robjectlist.h"
 #include "core/renvironmentobject.h"
 #include "misc/rkstandardicons.h"
 #include "misc/rkcommonfunctions.h"
+#include "misc/rkcompatibility.h"
 #include "misc/rkxmlguisyncer.h"
 #include "misc/rkdbusapi.h"
 #include "misc/rkdialogbuttonbox.h"
-#include "rkglobals.h"
-#include "dialogs/startupdialog.h"
+#include "misc/rkstyle.h"
 #include "dialogs/rkloadlibsdialog.h"
 #include "dialogs/rkimportdialog.h"
 #include "dialogs/rkrecoverdialog.h"
@@ -118,7 +119,6 @@ RKWardMainWindow::RKWardMainWindow () : KParts::MainWindow ((QWidget *)0, (Qt::W
 	rkward_mainwin = this;
 	katepluginintegration = nullptr;
 	active_ui_buddy = nullptr;
-	RKGlobals::rinter = nullptr;
 	RKCommonFunctions::getRKWardDataDir(); // call this before any forking, in order to avoid potential race conditions during initialization of data dir
 	RKSettings::settings_tracker = new RKSettingsTracker (this);
 
@@ -131,7 +131,7 @@ RKWardMainWindow::RKWardMainWindow () : KParts::MainWindow ((QWidget *)0, (Qt::W
 	RKWorkplace::mainWorkplace ()->initActions (actionCollection ());
 	setCentralWidget (RKWorkplace::mainWorkplace ());
 	connect (RKWorkplace::mainWorkplace ()->view (), &RKWorkplaceView::captionChanged, this, static_cast<void (RKWardMainWindow::*)(const QString&)>(&RKWardMainWindow::setCaption));
-	connect (RKWorkplace::mainWorkplace (), &RKWorkplace::workspaceUrlChanged, this, &RKWardMainWindow::addWorkspaceUrl);
+	connect (RKWorkplace::mainWorkplace (), &RKWorkplace::workspaceUrlChanged, [this](const QUrl &url) { RKRecentUrls::addRecentUrl(RKRecentUrls::workspaceId(), url); setCaption(QString()); });
 	initStatusBar();
 
 	part_manager = new KParts::PartManager (this);
@@ -140,8 +140,8 @@ RKWardMainWindow::RKWardMainWindow () : KParts::MainWindow ((QWidget *)0, (Qt::W
 	connect (partManager (), &KParts::PartManager::activePartChanged, this, &RKWardMainWindow::partChanged);
 
 	readOptions();
-	RKGlobals::mtracker = new RKModificationTracker (this);
-	initToolViewsAndR ();
+	new RKModificationTracker(this);
+	initToolViewsAndR();
 
 	///////////////////////////////////////////////////////////////////
 	// build the interface
@@ -178,17 +178,17 @@ RKWardMainWindow::RKWardMainWindow () : KParts::MainWindow ((QWidget *)0, (Qt::W
 RKWardMainWindow::~RKWardMainWindow() {
 	RK_TRACE (APP);
 
-	// these would not be strictly necessary, as we're exiting the app, anyway.
+	// these would not be strictly necessary, as we're exiting the app, anyway. (TODO: some deleted as QObject children, anyway. Clean up.)
 	delete RObjectList::getObjectList ();
 	delete RObjectBrowser::mainBrowser ();
 	delete RKCommandLog::getLog ();
 	delete RKConsole::mainConsole ();
 	delete RKHelpSearchWindow::mainHelpSearch ();
-	delete RKGlobals::tracker ();
-	delete RKGlobals::rInterface ();
+	delete RInterface::instance();
 	delete RControlWindow::getControl ();
 	factory ()->removeClient (RKComponentMap::getMap ());
 	delete RKComponentMap::getMap ();
+	RKStyle::cleanResources();
 }
 
 KatePluginIntegrationApp* RKWardMainWindow::katePluginIntegration () {
@@ -218,9 +218,9 @@ void RKWardMainWindow::closeEvent (QCloseEvent *e) {
 void RKWardMainWindow::doPostInit () {
 	RK_TRACE (APP);
 
-	QStringList open_urls = RKGlobals::startup_options.take ("initial_urls").toStringList ();
-	bool warn_external = RKGlobals::startup_options.take ("warn_external").toBool ();
-	QString evaluate_code = RKGlobals::startup_options.take ("evaluate").toString ();
+	QStringList open_urls = RKSettingsModuleGeneral::takeStartupOption("initial_urls").toStringList();
+	bool warn_external = RKSettingsModuleGeneral::takeStartupOption("warn_external").toBool();
+	QString evaluate_code = RKSettingsModuleGeneral::takeStartupOption("evaluate").toString();
 
 	initPlugins ();
 	gui_rebuild_locked = false;
@@ -244,7 +244,7 @@ void RKWardMainWindow::doPostInit () {
 
 	QString cd_to = RKSettingsModuleGeneral::initialWorkingDirectory ();
 	if (!cd_to.isEmpty ()) {
-		RKGlobals::rInterface ()->issueCommand ("setwd (" + RObject::rQuote (cd_to) + ")\n", RCommand::App);
+		RInterface::issueCommand ("setwd (" + RObject::rQuote (cd_to) + ")\n", RCommand::App);
 		QDir::setCurrent (cd_to);
 	}
 
@@ -255,16 +255,9 @@ void RKWardMainWindow::doPostInit () {
 
 		openUrlsFromCommandLineOrDBus (warn_external, open_urls);
 	} else {
-		StartupDialog::StartupDialogResult result = StartupDialog::getStartupAction (this, fileOpenRecentWorkspace);
-		if (!result.open_url.isEmpty ()) {
+		if (RKSettingsModuleGeneral::openRestoreFileOnLoad() && QFile::exists(".RData")) {
 			// setNoAskSave(true); was called earlier
-			askOpenWorkspace(result.open_url);
-		} else {
-			if (result.result == StartupDialog::ChoseFile) {
-				askOpenWorkspace (QUrl());
-			} else if (result.result == StartupDialog::EmptyTable) {
-				RKWorkplace::mainWorkplace ()->editNewDataFrame (i18n ("my.data"));
-			}
+			askOpenWorkspace(QUrl::fromLocalFile(QFileInfo(".RData").absoluteFilePath()));
 		}
 
 		if (RKSettingsModuleGeneral::workplaceSaveMode () == RKSettingsModuleGeneral::SaveWorkplaceWithSession) {
@@ -277,7 +270,7 @@ void RKWardMainWindow::doPostInit () {
 	// up to this point, no "real" save-worthy stuff can be pending in the backend. So mark this point as "clean".
 	RCommand *command = new RCommand (QString (), RCommand::EmptyCommand | RCommand::Sync | RCommand::App);
 	connect (command->notifier (), &RCommandNotifier::commandFinished, this, &RKWardMainWindow::setWorkspaceUnmodified);
-	RKGlobals::rInterface ()->issueCommand (command);
+	RInterface::issueCommand (command);
 
 	if (!evaluate_code.isEmpty ()) RKConsole::pipeUserCommand (evaluate_code);
 	RKDBusAPI *dbus = new RKDBusAPI (this);
@@ -285,7 +278,7 @@ void RKWardMainWindow::doPostInit () {
 	// around on the bus in this case.
 
 	updateCWD ();
-	connect (RKGlobals::rInterface (), &RInterface::backendWorkdirChanged, this, &RKWardMainWindow::updateCWD);
+	connect (RInterface::instance(), &RInterface::backendWorkdirChanged, this, &RKWardMainWindow::updateCWD);
 	setCaption (QString ());	// our version of setCaption takes care of creating a correct caption, so we do not need to provide it here
 }
 
@@ -332,16 +325,16 @@ void RKWardMainWindow::initPlugins (const QStringList &automatically_added) {
 		const QString &map = all_maps[i];
 		RKPluginMapParseResult result = RKComponentMap::getMap ()->addPluginMap (map);
 		if (!result.valid_plugins) {
-			RKSettingsModulePlugins::markPluginMapAsBroken (map);
+			RKSettingsModulePlugins::markPluginMapState(map, RKSettingsModulePlugins::Broken);
 			completely_broken_maps.append (map);
 			completely_broken_maps_details.append (result.detailed_problems);
 		} else if (!result.detailed_problems.isEmpty ()) {
-			if (RKSettingsModulePlugins::markPluginMapAsQuirky (map)) {
+			if (RKSettingsModulePlugins::markPluginMapState(map, RKSettingsModulePlugins::Quirky)) {
 				somewhat_broken_maps.append (map);
 				somewhat_broken_maps_details.append (result.detailed_problems);
 			}
 		} else {
-			RKSettingsModulePlugins::markPluginMapAsWorking (map);
+			RKSettingsModulePlugins::markPluginMapState(map, RKSettingsModulePlugins::Working);
 		}
 	}
 
@@ -367,7 +360,6 @@ void RKWardMainWindow::initPlugins (const QStringList &automatically_added) {
 
 void RKWardMainWindow::startR () {
 	RK_TRACE (APP);
-	RK_ASSERT (!RKGlobals::rInterface ());
 
 	// make sure our general purpose files directory exists
 	QString packages_path = RKSettingsModuleGeneral::filesPath() + "/.rkward_packages";
@@ -392,8 +384,8 @@ void RKWardMainWindow::startR () {
 		}
 	}
 
-	RKGlobals::rinter = new RInterface ();
-	connect(RKGlobals::rInterface(), &RInterface::backendStatusChanged, this, &RKWardMainWindow::setRStatus);
+	RInterface::create();
+	connect(RInterface::instance(), &RInterface::backendStatusChanged, this, &RKWardMainWindow::setRStatus);
 	new RObjectList ();
 
 	RObjectBrowser::mainBrowser ()->unlock ();
@@ -405,9 +397,9 @@ void RKWardMainWindow::slotConfigure () {
 }
 
 void RKWardMainWindow::slotCancelAllCommands () {
-	RK_TRACE (APP);
-	RK_ASSERT (RKGlobals::rInterface ());
-	RKGlobals::rInterface ()->cancelAll ();
+	RK_TRACE(APP);
+	RK_ASSERT(RInterface::instance());
+	RInterface::instance()->cancelAll();
 }
 
 void RKWardMainWindow::configureCarbonCopy () {
@@ -491,7 +483,8 @@ void RKWardMainWindow::initActions() {
 	new_output->setIcon(RKStandardIcons::getIcon(RKStandardIcons::WindowOutput));
 	new_output->setWhatsThis(i18n("Creates and activates a new output document"));
 
-	fileOpenScript = actionCollection()->addAction(KStandardAction::Open, "file_open_script", this, SLOT(slotOpenCommandEditor()));
+	fileOpenScript = actionCollection()->addAction(KStandardAction::Open, "file_open_script");
+	connect(fileOpenScript, &QAction::triggered, this, [this]() { slotOpenCommandEditor(); });
 	actionCollection()->setDefaultShortcut(fileOpenScript, Qt::ControlModifier + Qt::AltModifier + Qt::Key_O);
 	fileOpenScript->setText(i18n("Open R Script File..."));
 
@@ -503,29 +496,25 @@ void RKWardMainWindow::initActions() {
 	connect (file_open_any, &QAction::triggered, this, &RKWardMainWindow::openAnyFile);
 	file_open_any->setText (i18n ("Open any File..."));
 
-	fileOpenRecent = static_cast<KRecentFilesAction*> (actionCollection ()->addAction (KStandardAction::OpenRecent, "file_open_recenty", this, SLOT(slotOpenCommandEditor(QUrl))));
-	fileOpenRecent->setText (i18n ("Open Recent R Script File"));
+	fileOpenRecent = RKRecentUrls::claimAction(RKRecentUrls::scriptsId());
+	actionCollection ()->addAction("file_open_recenty", fileOpenRecent);
+	connect(fileOpenRecent, &KRecentFilesAction::urlSelected, this, [this](const QUrl &url) { slotOpenCommandEditor(url); });
+	fileOpenRecent->setText(i18n("Open Recent R Script File"));
 
-#if 0
-	// TODO: Fix import dialog and re-enable it: https://mail.kde.org/pipermail/rkward-devel/2015-June/004156.html
-#ifdef Q_OS_WIN
-	// TODO: find the cause and fix it! http://sourceforge.net/p/rkward/bugs/54/
-#	ifdef __GNUC__
-#		warning TODO: import data dialog is disabled on windows due to bug in kdelibs
-#	endif
-#else
-	action = actionCollection ()->addAction ("import_data", this, SLOT (importData()));
-	action->setText (i18n ("Import Data"));
-	action->setWhatsThis(i18n ("Import data from a variety of file formats"));
-#endif
-#endif
+	action = actionCollection()->addAction("import_data");
+	connect(action, &QAction::triggered, this, &RKWardMainWindow::importData);
+	action->setText(i18n("Import Assistant"));
+	action->setWhatsThis(i18n("Assistant to find the best method to import data from a variety of formats"));
 
-	fileOpenWorkspace = actionCollection ()->addAction (KStandardAction::Open, "file_openx", this, SLOT(slotFileOpenWorkspace()));
+	fileOpenWorkspace = actionCollection()->addAction(KStandardAction::Open, "file_openx");
+	connect(fileOpenWorkspace, &QAction::triggered, this, [this](){ askOpenWorkspace(); });
 	fileOpenWorkspace->setText (i18n ("Open Workspace..."));
 	actionCollection ()->setDefaultShortcut (fileOpenWorkspace, Qt::ControlModifier + Qt::ShiftModifier + Qt::Key_O);
 	fileOpenWorkspace->setWhatsThis(i18n ("Opens an existing document"));
 
-	fileOpenRecentWorkspace = static_cast<KRecentFilesAction*> (actionCollection ()->addAction (KStandardAction::OpenRecent, "file_open_recentx", this, SLOT(askOpenWorkspace(QUrl))));
+	fileOpenRecentWorkspace = RKRecentUrls::claimAction(RKRecentUrls::workspaceId());
+	actionCollection ()->addAction("file_open_recentx", fileOpenRecentWorkspace);
+	connect(fileOpenRecentWorkspace, &KRecentFilesAction::urlSelected, this, &RKWardMainWindow::askOpenWorkspace);
 	fileOpenRecentWorkspace->setText (i18n ("Open Recent Workspace"));
 	fileOpenRecentWorkspace->setWhatsThis(i18n ("Opens a recently used file"));
 
@@ -762,10 +751,8 @@ void RKWardMainWindow::saveOptions () {
 // TODO: WORKAROUND. See corresponding line in readOptions ()
 	cg.writeEntry("Geometry", size ());
 
-	fileOpenRecentWorkspace->saveEntries (config->group ("Recent Files"));
-	fileOpenRecent->saveEntries (config->group ("Recent Command Files"));
-
-	RKSettings::saveSettings (config.data ());
+	RKRecentUrls::saveConfig();
+	RKSettings::saveSettings(config.data());
 
 	config->sync ();
 }
@@ -784,16 +771,12 @@ void RKWardMainWindow::readOptions () {
 	KConfigGroup cg = config->group ("General Options");
 	QSize size = cg.readEntry ("Geometry", QSize ());
 	if (size.isEmpty ()) {
-		size = RKCommonFunctions::availableGeometry(this).size();
+		size = RKCompatibility::availableGeometry(this).size();
 	}
 	resize (size);
 
 	RKSettings::loadSettings (config.data ());
 
-	// initialize the recent file list
-	fileOpenRecentWorkspace->loadEntries (config->group ("Recent Files"));
-	fileOpenRecent->setMaxItems (RKSettingsModuleCommandEditor::maxNumRecentFiles ());
-	fileOpenRecent->loadEntries (config->group ("Recent Command Files"));
 	statusBar()->hide();
 }
 
@@ -834,20 +817,14 @@ void RKWardMainWindow::askOpenWorkspace (const QUrl &url) {
 	slotSetStatusBarText(i18n("Opening workspace..."));
 	QUrl lurl = url;
 	if (lurl.isEmpty ()) {
-		lurl = QFileDialog::getOpenFileUrl(this, i18n("Select workspace to open..."), RKSettingsModuleGeneral::lastUsedUrlFor("workspaces"), i18n("R Workspace Files [%1](%1);;All files [*](*)", RKSettingsModuleGeneral::workspaceFilenameFilter()));
+		lurl = QFileDialog::getOpenFileUrl(this, i18n("Select workspace to open..."), RKRecentUrls::mostRecentUrl(RKRecentUrls::workspaceId()).adjusted(QUrl::RemoveFilename), i18n("R Workspace Files [%1](%1);;All files [*](*)", RKSettingsModuleGeneral::workspaceFilenameFilter()));
 	}
 	if (!lurl.isEmpty ()) {
-		RKSettingsModuleGeneral::updateLastUsedUrl("workspaces", lurl.adjusted(QUrl::RemoveFilename));
 		new RKLoadAgent(lurl, merge_loads);
 	}
 	slotSetStatusReady();
 }
 
-void RKWardMainWindow::slotFileOpenWorkspace () {
-	RK_TRACE (APP);
-	askOpenWorkspace (QUrl ());
-}
-
 void RKWardMainWindow::slotFileLoadLibs () {
 	RK_TRACE (APP);
 	RKLoadLibsDialog *dial = new RKLoadLibsDialog (this, 0);
@@ -864,13 +841,6 @@ void RKWardMainWindow::slotFileSaveWorkspaceAs () {
 	RKSaveAgent::saveWorkspaceAs();
 }
 
-void RKWardMainWindow::addWorkspaceUrl (const QUrl &url) {
-	RK_TRACE (APP);
-
-	if (!url.isEmpty ()) fileOpenRecentWorkspace->addUrl (url);
-	setCaption (QString ());	// trigger update of caption
-}
-
 void RKWardMainWindow::updateCWD () {
 	RK_TRACE (APP);
 
@@ -915,10 +885,9 @@ void RKWardMainWindow::slotDetachWindow () {
 }
 
 void setIndictatorColor(QWidget *widget, KColorScheme::ForegroundRole fg, KColorScheme::BackgroundRole bg) {
-	KColorScheme color_scheme(QPalette::Normal); // default parameter in more recent versions of KColorScheme (->KF6: remove)
 	QPalette palette = widget->palette();
-	palette.setBrush(widget->backgroundRole(), color_scheme.background(bg));
-	palette.setBrush(widget->foregroundRole(), color_scheme.foreground(fg));
+	palette.setBrush(widget->backgroundRole(), RKStyle::viewScheme()->background(bg));
+	palette.setBrush(widget->foregroundRole(), RKStyle::viewScheme()->foreground(fg));
 	widget->setAutoFillBackground(true);
 	widget->setPalette(palette);
 }
@@ -944,28 +913,23 @@ void RKWardMainWindow::setRStatus (int status) {
 	}
 }
 
-void RKWardMainWindow::importData () {
+void RKWardMainWindow::importData() {
 	RK_TRACE (APP);
 
-	new RKImportDialog ("import", this);
+	RKImportDialog d("import", this);
+	d.exec();
 }
 
 void RKWardMainWindow::slotNewCommandEditor () {
 	RK_TRACE (APP);
 
-	slotOpenCommandEditor (QUrl ());
-}
-
-void RKWardMainWindow::addScriptUrl (const QUrl &url) {
-	RK_TRACE (APP);
-
-	if (!url.isEmpty ()) fileOpenRecent->addUrl (url);
+	RKWorkplace::mainWorkplace()->openScriptEditor();
 }
 
 void RKWardMainWindow::openAnyFile () {
 	RK_TRACE (APP);
 
-	QFileDialog* dialog = new QFileDialog (0, QString (), RKSettingsModuleGeneral::lastUsedUrlFor ("rscripts").toLocalFile (), QString ("*|All Files (*)\n%1|R Script Files (%1)").arg (RKSettingsModuleCommandEditor::scriptFileFilter ()));
+	QFileDialog* dialog = new QFileDialog (0, QString (), RKRecentUrls::mostRecentUrl(RKRecentUrls::scriptsId()).adjusted(QUrl::RemoveFilename).toLocalFile(), QString ("*|All Files (*)\n%1|R Script Files (%1)").arg (RKSettingsModuleCommandEditor::scriptFileFilter ()));
 	dialog->setFileMode (QFileDialog::ExistingFiles);
 
 // Create a type selection widget, and hack it into the dialog:
@@ -995,13 +959,10 @@ void RKWardMainWindow::openAnyFile () {
 		RKWorkplace::mainWorkplace ()->openAnyUrl (url);
 	} else if (mode == 1) {
 		RKWorkplace::mainWorkplace ()->openScriptEditor (url);
-		RKSettingsModuleGeneral::updateLastUsedUrl ("rscripts", url.adjusted (QUrl::RemoveFilename));
 	} else if (mode == 2) {
 		RKWorkplace::mainWorkplace ()->openScriptEditor (url, QString (), RKCommandEditorFlags::DefaultFlags | RKCommandEditorFlags::ForceRHighlighting);
-		RKSettingsModuleGeneral::updateLastUsedUrl ("rscripts", url.adjusted (QUrl::RemoveFilename));
 	} else if (mode == 3) {
 		askOpenWorkspace(url);
-		RKSettingsModuleGeneral::updateLastUsedUrl ("workspaces", url.adjusted (QUrl::RemoveFilename));
 	}
 }
 
@@ -1011,29 +972,28 @@ void RKWardMainWindow::slotNewOutput() {
 	RKWorkplace::mainWorkplace()->openOutputWindow(QUrl(), true);
 }
 
-void RKWardMainWindow::slotOpenOutput() {
+void RKWardMainWindow::slotOpenOutput(const QUrl &_url) {
 	RK_TRACE (APP);
 
-	QUrl url = QFileDialog::getOpenFileUrl(this, i18n("Select RKWard Output file to open..."), RKSettingsModuleGeneral::lastUsedUrlFor("output"), i18n("RKWard Output Files [*.rko](*.rko);;All files [*](*)"));
+	QUrl url(_url);
+	if (url.isEmpty()) {
+		url = QFileDialog::getOpenFileUrl(this, i18n("Select RKWard Output file to open..."), RKRecentUrls::mostRecentUrl(RKRecentUrls::outputId()).adjusted(QUrl::RemoveFilename), i18n("RKWard Output Files [*.rko](*.rko);;All files [*](*)"));
+	}
 	RKWorkplace::mainWorkplace()->openOutputWindow(url);
 }
 
 void RKWardMainWindow::slotOpenCommandEditor (const QUrl &url, const QString &encoding) {
 	RK_TRACE (APP);
 
-	RKWorkplace::mainWorkplace ()->openScriptEditor (url, encoding);
-}
-
-void RKWardMainWindow::slotOpenCommandEditor () {
-	RK_TRACE (APP);
-	KEncodingFileDialog::Result res;
-
-	res = KEncodingFileDialog::getOpenUrlsAndEncoding (QString (), RKSettingsModuleGeneral::lastUsedUrlFor ("rscripts"), QString ("%1|R Script Files (%1)\n*|All Files (*)").arg (RKSettingsModuleCommandEditor::scriptFileFilter ()), this, i18n ("Open script file(s)"));
-	for (int i = 0; i < res.URLs.size (); ++i) {
-		if (i == 0) RKSettingsModuleGeneral::updateLastUsedUrl ("rscripts", res.URLs[i].adjusted (QUrl::RemoveFilename));
-		slotOpenCommandEditor (res.URLs[i], res.encoding);
+	if (url.isEmpty()) {
+		auto res = KEncodingFileDialog::getOpenUrlsAndEncoding(QString(), RKRecentUrls::mostRecentUrl(RKRecentUrls::scriptsId()).adjusted(QUrl::RemoveFilename), QString("%1|R Script Files (%1)\n*|All Files (*)").arg(RKSettingsModuleCommandEditor::scriptFileFilter()), this, i18n("Open script file(s)"));
+		for (int i = 0; i < res.URLs.size(); ++i) {
+				RKWorkplace::mainWorkplace ()->openScriptEditor(res.URLs[i], res.encoding);
+		}
+	} else {
+		RKWorkplace::mainWorkplace ()->openScriptEditor(url, encoding);
 	}
-};
+}
 
 void RKWardMainWindow::setCaption (const QString &) {
 	RK_TRACE (APP);
