@@ -15,8 +15,8 @@ SPDX-License-Identifier: GPL-2.0-or-later
 class QLabel;
 class QCloseEvent;
 class KActionMenu;
-class RKTopLevelWindowGUI;
 class KRecentFilesAction;
+class RKTopLevelWindowGUI;
 class KSqueezedTextLabel;
 class QAction;
 class KatePluginIntegrationApp;
@@ -72,11 +72,9 @@ public slots:
 	/** open a workspace. If the current workspace is not empty, ask whether to save first.
     @see setNoAskSave ()
     @see setWorkspaceMightBeModified () */
-	void askOpenWorkspace (const QUrl &url);
+	void askOpenWorkspace (const QUrl &url=QUrl());
 	/** creates a new (empty) data.frame */
 	void slotNewDataFrame ();
-	/** open a file and load it into the document*/
-	void slotFileOpenWorkspace();
 	/** save a document */
 	void slotFileSaveWorkspace();
 	/** save a document by a new filename*/
@@ -99,25 +97,18 @@ public slots:
 /** configures RKward-settings */
 	void slotConfigure ();
 
-/** Add the given url to the list of recent scripts */
-	void addScriptUrl (const QUrl &url);
-/** Add the given url to the list of recent workspaces */
-	void addWorkspaceUrl (const QUrl &url);
-
 	/** Init-procedures to be done after the exec-loop was started */
 	void doPostInit ();
 
 /** open a new command editor (blank file) */
 	void slotNewCommandEditor();
-/** open a new command editor (ask for file to open) */
-	void slotOpenCommandEditor ();
-/** open a new command editor (load given url) */
-	void slotOpenCommandEditor (const QUrl &url, const QString& encoding = QString ());
+/** open a new command editor (load given url, ask for url to load, if empty) */
+	void slotOpenCommandEditor (const QUrl &url = QUrl(), const QString& encoding = QString());
 
 /** create and show a new output window */
 	void slotNewOutput();
 /** load an output Window (ask for file to open) */
-	void slotOpenOutput();
+	void slotOpenOutput(const QUrl &url=QUrl());
 
 /** close current window (Windows->Close). */
 	void slotCloseWindow ();
