@@ -34,6 +34,31 @@ QtScriptBackend::~QtScriptBackend () {
 	if (script_thread && script_thread->isRunning ()) script_thread->terminate ();
 }
 
+#ifdef JSBACKEND_PERFORMANCE_TEST
+#include <QElapsedTimer>
+#include <QApplication>
+#include <QObjectCleanupHandler>
+#include "../misc/rkmessagecatalog.h"
+void QtScriptBackend::_performanceTest() {
+	RK_DEBUG(PHP, DL_WARNING, "Starting QtScriptBackend performance test");
+	QElapsedTimer t;
+	QObjectCleanupHandler h;
+	t.start();
+	for (int i = 0; i < 1000; ++i) {
+		auto b = new QtScriptBackend(QString(), RKMessageCatalog::nullCatalog());
+		b->dead = true; // so it doesn't try to show an error message
+		h.add(b);
+		b->initialize(nullptr, false);
+		connect(b->script_thread, &QtScriptBackendThread::error, b, &QObject::deleteLater);  // thread will throw an error, when trying to include non-existent script file
+	}
+	while (!h.isEmpty()) {
+		qApp->processEvents();
+	}
+	RK_DEBUG(PHP, DL_WARNING, "Time to init 100 backends: %d", t.elapsed());
+	RK_DEBUG(PHP, DL_WARNING, "QtScriptBackend performance test end");
+}
+#endif
+
 bool QtScriptBackend::initialize (RKComponentPropertyCode *code_property, bool add_headings) {
 	RK_TRACE (PHP);
 
@@ -74,26 +99,27 @@ void QtScriptBackend::destroy () {
 void QtScriptBackend::tryNextFunction () {
 	RK_TRACE (PHP);
 
-	if (script_thread && (!busy) && (!command_stack.isEmpty ())) {
+	if (script_thread && (!busy) && (!command_stack.empty())) {
 	/// clean up previous command if applicable
-		if (command_stack.first ()->complete) {
-			delete command_stack.takeFirst ();
+		if (command_stack.front()->complete) {
+			delete command_stack.front();
+			command_stack.pop_front();
 			
-			if (command_stack.isEmpty ()) {
+			if (command_stack.empty ()) {
 				script_thread->goToSleep (true);
 				return;
 			}
 		}
 		
-		RK_DEBUG (PHP, DL_DEBUG, "submitting QtScript code: %s", command_stack.first ()->command.toLatin1 ().data ());
+		RK_DEBUG(PHP, DL_DEBUG, "submitting QtScript code: %s", qPrintable(command_stack.front()->command));
 		if (script_thread) script_thread->goToSleep (false);
-		script_thread->setCommand (command_stack.first ()->command);
+		script_thread->setCommand(command_stack.front()->command);
 		busy = true;
-		command_stack.first ()->complete = true;
-		current_flags = command_stack.first ()->flags;
-		current_type = command_stack.first ()->type;
+		command_stack.front()->complete = true;
+		current_flags = command_stack.front()->flags;
+		current_type = command_stack.front()->type;
 	} else {
-		if (script_thread && command_stack.isEmpty ()) script_thread->goToSleep (true);
+		if (script_thread && command_stack.empty()) script_thread->goToSleep (true);
 	}
 }
 
@@ -224,7 +250,6 @@ QVariant QtScriptBackendThread::getUiLabelPair (const QString &identifier) {
 	return getValue (identifier, RKStandardComponent::UiLabelPair);
 }
 
-#ifdef USE_QJSENGINE
 bool QtScriptBackendThread::scriptError(const QJSValue &val) {
 	RK_TRACE (PHP);
 
@@ -235,20 +260,6 @@ bool QtScriptBackendThread::scriptError(const QJSValue &val) {
 
 	return true;
 }
-#else
-bool QtScriptBackendThread::scriptError(const RKJSValue &val) {
-	RK_TRACE (PHP);
-	Q_UNUSED(val);
-
-	if (!engine.hasUncaughtException ()) return false;
-
-	QString message = i18n ("Script Error: %1\nBacktrace:\n%2", engine.uncaughtException ().toString (), engine.uncaughtExceptionBacktrace ().join ("\n"));
-	engine.clearExceptions ();
-	emit error(message);
-
-	return true;
-}
-#endif
 
 bool QtScriptBackendThread::includeFile (const QString &filename) {
 	RK_TRACE (PHP);
@@ -259,17 +270,13 @@ bool QtScriptBackendThread::includeFile (const QString &filename) {
 		_filename = script_path.toLocalFile ();
 	}
 
-		QFile file (_filename);
-		if (!file.open (QIODevice::ReadOnly | QIODevice::Text)) {
+	QFile file(_filename);
+	if (!file.open (QIODevice::ReadOnly | QIODevice::Text)) {
 		emit error(i18n("The file \"%1\" (needed by \"%2\") could not be found. Please check your installation.", _filename, _scriptfile));
 		return false;
 	}
 
-#ifndef USE_QJSENGINE
-	// evaluate in global context
-	engine.currentContext ()->setActivationObject (engine.globalObject ());
-#endif
-	RKJSValue result = engine.evaluate (QString::fromUtf8 (file.readAll ()), _filename);
+	QJSValue result = engine.evaluate (QString::fromUtf8 (file.readAll ()), _filename);
 	if (scriptError(result)) return false;
 
 	return true;
@@ -278,22 +285,11 @@ bool QtScriptBackendThread::includeFile (const QString &filename) {
 void QtScriptBackendThread::run () {
 	RK_TRACE (PHP);
 
-	RKJSValue backend_object = engine.newQObject (this);
+	QJSValue backend_object = engine.newQObject (this);
 	engine.globalObject ().setProperty ("_RK_backend", backend_object);
 	RKMessageCatalogObject::addI18nToScriptEngine (&engine, catalog);
 
-#ifdef USE_Q_SCRIPT_PROGRAM
-	if (!RKPrecompiledQtScripts::loadCommonScript (&engine, _commonfile)) {
-		if (!engine.hasUncaughtException ()) {
-			emit error (i18n ("Could not open common script file \"%1\"", _commonfile));
-		} else {
-			scriptError (QScriptValue());
-		}
-		return;
-	}
-#else
-	if (!includeFile (_commonfile)) return;
-#endif
+	if (!includeFile (_commonfile)) return;  // TODO: import this as a module and re-use the engine in the next thread?
 	if (!includeFile (_scriptfile)) return;
 
 	emit commandDone("startup complete");
@@ -319,48 +315,10 @@ void QtScriptBackendThread::run () {
 		}
 
 		// do it!
-		RKJSValue result = engine.evaluate (command);
+		QJSValue result = engine.evaluate (command);
 		if (scriptError(result)) return;
 		emit commandDone(result.toString());
 
 		command.clear ();
 	}
 }
-
-#ifdef USE_Q_SCRIPT_PROGRAM
-namespace RKPrecompiledQtScripts {
-	QMap<QString, QScriptProgram> compiled_includes;
-	QMutex compiled_includes_mutex;
-
-	bool loadCommonScript (QScriptEngine* engine, const QString &scriptfile) {
-		RK_TRACE (PHP);
-
-		// NOTE: QScriptProgram cannot be evaluated concurrently in several threads (see https://bugreports.qt-project.org/browse/QTBUG-29246).
-		// Neither would our QMap caching logic work in concurrent threads. Thus the mutex. This clearly has the drawback that QScript evaluation threads
-		// may be waiting for each other during initialization. However, we assume that
-		// - Typically only few such threads are running
-		// - Responsiveness (i.e. UI startup speed), not throughput is the main goal, here.
-		// - The important script engines are those running in the UI thread (and thus necessarily sequentially). As long as these are initialized before
-		//   the other threads, they will clearly profit from pre-compiling
-		QMutexLocker ml (&compiled_includes_mutex);
-		if (!compiled_includes.contains (scriptfile)) {
-			RK_DEBUG (PHP, DL_DEBUG, "Compiling common script file %s", qPrintable (scriptfile));
-			QFile file (scriptfile);
-			if (!file.open (QIODevice::ReadOnly | QIODevice::Text)) {
-				return false;
-			}
-			compiled_includes.insert (scriptfile, QScriptProgram (QString::fromUtf8 (file.readAll ()), scriptfile));
-			file.close ();
-		} else {
-			RK_DEBUG (PHP, DL_DEBUG, "Script file %s is already compiled", qPrintable (scriptfile));
-		}
-		engine->evaluate (compiled_includes[scriptfile]);
-		if (engine->hasUncaughtException ()) {
-			compiled_includes.remove (scriptfile);
-			return false;
-		}
-		return true;
-	}
-}
-#endif
-
