@@ -20,10 +20,11 @@ SPDX-License-Identifier: GPL-2.0-or-later
 #include <QRadioButton>
 #include <QSpinBox>
 
-#include "../rkglobals.h"
+#include "../misc/rkstyle.h"
 #include "../rbackend/rkrinterface.h"
 #include "../misc/rkspinbox.h"
 #include "../misc/rkcommonfunctions.h"
+#include "../misc/rkcompatibility.h"
 #include "../misc/rkstandardicons.h"
 #include "../core/robject.h"
 #include "../debug.h"
@@ -44,7 +45,7 @@ RKSettingsModuleGraphics::RKSettingsModuleGraphics (RKSettings *gui, QWidget *pa
 
 	QVBoxLayout *main_vbox = new QVBoxLayout (this);
 
-	QHBoxLayout *h_layout1 = new QHBoxLayout (this);
+	QHBoxLayout *h_layout1 = new QHBoxLayout();
 	main_vbox->addLayout (h_layout1);
 	QGroupBox *group = new QGroupBox (i18n ("Default graphics device"), this);
 	default_device_group = new QButtonGroup (this);
@@ -68,7 +69,7 @@ RKSettingsModuleGraphics::RKSettingsModuleGraphics (RKSettings *gui, QWidget *pa
 	                                  "<p>The RKWard native device is the recommended choice for most users. This corresponds to the R command <i>RK()</i>.</p>"
 	                                  "<p>The 'Platform default device' corresponds to one of <i>X11()</i>, <i>windows()</i>, or <i>quartz()</i>, depending on the platform.</p>"
 	                                  "<p>You can also specify the name of a function such as <i>cairoDevice</i>.</p>"), group);
-	connect (default_device_group, static_cast<void (QButtonGroup::*)(int)>(&QButtonGroup::buttonClicked), this, &RKSettingsModuleGraphics::boxChanged);
+	connect (default_device_group, RKCompatibility::groupButtonClicked(), this, &RKSettingsModuleGraphics::boxChanged);
 	connect (default_device_other_edit, &QLineEdit::textChanged, this, &RKSettingsModuleGraphics::boxChanged);
 	h_layout1->addWidget (group);
 
@@ -98,14 +99,14 @@ RKSettingsModuleGraphics::RKSettingsModuleGraphics (RKSettings *gui, QWidget *pa
 	                                  "<li>The original platform specific devices can be used unchanged, without the addition of RKWard specific features.</li></ul>"
 	                                  "<p>Regardless of this setting, the original devices are always accessible as <i>grDevices::X11()</i>, etc.</p>"
 	                                  "<p>Using a device on a platform where it is not defined (e.g. <i>Windows()</i> on Mac OS X) will always fall back to the <i>RK()</i> device.</p>"), group);
-	connect (replace_standard_devices_group, static_cast<void (QButtonGroup::*)(int)>(&QButtonGroup::buttonClicked), this, &RKSettingsModuleGraphics::boxChanged);
+	connect (replace_standard_devices_group, RKCompatibility::groupButtonClicked(), this, &RKSettingsModuleGraphics::boxChanged);
 	h_layout1->addWidget (group);
 
 	group = new QGroupBox(i18n("Default window size (for RK(), or embedded device windows)"));
 	group_layout = new QVBoxLayout(group);
 	group_layout->addWidget(new QLabel(i18n("Default width (inches):")));
 	group_layout->addWidget(graphics_width.makeSpinBox(1, 100.0, this));
-	group_layout->addSpacing(2*RKGlobals::spacingHint());
+	group_layout->addSpacing(2*RKStyle::spacingHint());
 	group_layout->addWidget(new QLabel(i18n("Default height (inches)")));
 	group_layout->addWidget(graphics_height.makeSpinBox(1, 100.0, this));
 	main_vbox->addWidget (group);
@@ -170,7 +171,7 @@ void RKSettingsModuleGraphics::applyChanges () {
 
 	QStringList commands = makeRRunTimeOptionCommands ();
 	for (QStringList::const_iterator it = commands.cbegin (); it != commands.cend (); ++it) {
-		RKGlobals::rInterface ()->issueCommand (*it, RCommand::App, QString (), 0, 0, commandChain ());
+		RInterface::issueCommand (*it, RCommand::App, QString (), 0, 0, commandChain ());
 	}
 }
 
