@@ -35,16 +35,16 @@ SPDX-License-Identifier: GPL-2.0-or-later
 #include <QCheckBox>
 #include <QFileDialog>
 
-#include "../rkglobals.h"
 #include "../rbackend/rkrinterface.h"
 #include "rkhelpsearchwindow.h"
 #include "../rkward.h"
 #include "../rkconsole.h"
-#include "../settings/rksettingsmodulegeneral.h"
+#include "../settings/rkrecenturls.h"
 #include "../settings/rksettingsmoduler.h"
 #include "../settings/rksettings.h"
 #include "../settings/rksettingsmoduleoutput.h"
 #include "../misc/rkcommonfunctions.h"
+#include "../misc/rkcompatibility.h"
 #include "../misc/rkstandardactions.h"
 #include "../misc/rkstandardicons.h"
 #include "../misc/xmlhelper.h"
@@ -53,11 +53,16 @@ SPDX-License-Identifier: GPL-2.0-or-later
 #include "../misc/rkmessagecatalog.h"
 #include "../misc/rkfindbar.h"
 #include "../misc/rkoutputdirectory.h"
+#include "../misc/rkstyle.h"
 #include "../plugin/rkcomponentmap.h"
 #include "../windows/rkworkplace.h"
 #include "../windows/rkworkplaceview.h"
 #include "../debug.h"
 
+QUrl restorableUrl(const QUrl &url) {
+	return QUrl(url.url().replace(RKSettingsModuleR::helpBaseUrl(), "rkward://RHELPBASE"));
+}
+
 #ifdef NO_QT_WEBENGINE
 #	include <QWebFrame>
 #	include <QNetworkRequest>
@@ -109,8 +114,9 @@ public:
 	QUrl url () {
 		return mainFrame ()->url ();
 	}
-	void setHtml (const QString &html) {
-		mainFrame ()->setHtml (html);
+	void setHtmlWrapper(const QString &html, const QUrl &baseurl) {
+		direct_load = true;
+		mainFrame()->setHtml(html, baseurl);
 	}
 	QPointF scrollPosition () const {
 		return mainFrame ()->scrollPosition ();
@@ -127,6 +133,10 @@ public:
 		});
 	}
 #else
+	void setHtmlWrapper(const QString &html, const QUrl &baseurl) {
+		direct_load = true;
+		setHtml(html, baseurl);
+	}
 	bool supportsContentType (const QString &name) {
 		if (name.startsWith("text")) return true;
 #ifdef __GNUC__
@@ -176,7 +186,7 @@ protected:
 		if (RKHTMLWindow::new_window) {
 			RK_ASSERT (RKHTMLWindow::new_window == this);
 			RK_ASSERT (!window);
-			RKWorkplace::mainWorkplace ()->openAnyUrl (navurl);
+			RKWorkplace::mainWorkplace()->openAnyUrl(restorableUrl(navurl));
 			RKHTMLWindow::new_window = nullptr;
 			if (!window) deleteLater ();  // this page was _not_ reused
 			return false;
@@ -308,12 +318,15 @@ RKHTMLWindow::RKHTMLWindow (QWidget *parent, WindowMode mode) : RKMDIWindow (par
 	// Apply current color scheme to page. This needs support in the CSS of the page, so will only work for RKWard help and output pages.
 	// Note that the CSS in those pages also has "automatic" support for dark mode ("prefers-color-scheme: dark"; but see https://bugreports.qt.io/browse/QTBUG-89753), however, 
 	// for a seamless appearance, the only option is to set the theme colors dynamically, via javascript.
-	auto scheme = KColorScheme(QPalette::Normal);
+	auto scheme = RKStyle::viewScheme();
 	QString color_scheme_js = QStringLiteral("function rksetcolor(name, value) { document.querySelector(':root').style.setProperty(name, value); }\n"
 	                                                "rksetcolor('--regular-text-color', '%1');\n"
 	                                                "rksetcolor('--background-color', '%2');\n"
 	                                                "rksetcolor('--header-color', '%3');\n"
-	                                                "rksetcolor('--anchor-color', '%4');").arg(scheme.foreground().color().name(), scheme.background().color().name(), scheme.foreground(KColorScheme::VisitedText).color().name(), scheme.foreground(KColorScheme::LinkText).color().name());
+	                                                "rksetcolor('--anchor-color', '%4');\n"
+	                                                "rksetcolor('--shadow-color', '%5');").arg(scheme->foreground().color().name(), scheme->background().color().name(),
+	                                                scheme->foreground(KColorScheme::VisitedText).color().name(), scheme->foreground(KColorScheme::LinkText).color().name(),
+	                                                scheme->shade(KColorScheme::MidShade).name());
 #ifdef NO_QT_WEBENGINE
 	connect(page, &RKWebPage::loadFinished, [this, color_scheme_js](){
 		page->mainFrame()->evaluateJavaScript(color_scheme_js);
@@ -377,8 +390,7 @@ RKHTMLWindow::~RKHTMLWindow () {
 
 QUrl RKHTMLWindow::restorableUrl () {
 	RK_TRACE (APP);
-
-	return QUrl ((current_url.url ().replace (RKSettingsModuleR::helpBaseUrl(), "rkward://RHELPBASE")));
+	return ::restorableUrl(current_url);
 }
 
 bool RKHTMLWindow::isModified () {
@@ -520,18 +532,22 @@ void RKHTMLWindow::slotBack () {
 	openLocationFromHistory (url_history[current_history_position]);
 }
 
+static bool isRKWardUrl(const QUrl &url) {
+	return url.scheme() == QStringLiteral("rkward");
+}
+
 void RKHTMLWindow::openRKHPage (const QUrl &url) {
 	RK_TRACE (APP);
 
-	RK_ASSERT (url.scheme () == "rkward");
-	changeURL (url);
+	RK_ASSERT(isRKWardUrl(url));
+	if (url != this->url()) changeURL(url);  // see ::refresh()
 	bool ok = false;
 	if ((url.host () == "component") || (url.host () == "page")) {
 		useMode (HTMLHelpWindow);
 
 		startNewCacheFile ();
 		RKHelpRenderer render (current_cache_file);
-		ok = render.renderRKHelp (url);
+		ok = render.renderRKHelp(url, this);
 		current_cache_file->close ();
 
 		QUrl cache_url = QUrl::fromLocalFile (current_cache_file->fileName ());
@@ -553,13 +569,13 @@ void RKHTMLWindow::openRKHPage (const QUrl &url) {
 bool RKHTMLWindow::handleRKWardURL (const QUrl &url, RKHTMLWindow *window) {
 	RK_TRACE (APP);
 
-	if (url.scheme () == "rkward") {
+	if (isRKWardUrl(url)) {
 		if (url.host () == "runplugin") {
 			QString path = url.path ();
 			if (path.startsWith ('/')) path = path.mid (1);
 			int sep = path.indexOf ('/');
 			// NOTE: These links may originate externally, even from untrusted sources. The submit mode *must* remain "ManualSubmit" for this reason!
-			RKComponentMap::invokeComponent (path.left (sep), path.mid (sep+1).split ('\n', QString::SkipEmptyParts), RKComponentMap::ManualSubmit);
+			RKComponentMap::invokeComponent (path.left (sep), path.mid (sep+1).split ('\n', RKCompatibility::SkipEmptyParts()), RKComponentMap::ManualSubmit);
 		} else if (url.host () == "rhelp") {
 			// TODO: find a nice solution to render this in the current window
 			QStringList spec = url.path ().mid (1).split ('/');
@@ -572,6 +588,37 @@ bool RKHTMLWindow::handleRKWardURL (const QUrl &url, RKHTMLWindow *window) {
 			QString path = url.path ();
 			if (path.startsWith ('/')) path = path.mid (1);
 			RKSettings::configureSettings(path);
+		} else if (url.host () == "open") {
+			QString path = url.path().mid(1); // skip initial '/'
+			int sep = path.indexOf('/');
+			QString category = path.left(sep);
+			path = path.mid(sep+1);
+			RK_DEBUG(APP, DL_DEBUG, "rkward://open: %s -> %s , %s", qPrintable(url.path()), qPrintable(category), qPrintable(path));
+			QUrl target;
+			if (!path.isEmpty()) target = QUrl::fromUserInput(path);
+			if (category == RKRecentUrls::scriptsId()) {
+				RKWardMainWindow::getMain()->slotOpenCommandEditor(target);
+			} else if (category == RKRecentUrls::workspaceId()) {
+				// This window will be destroyed while closing the previous workspace. Thus wait for the next event cycle.
+				QTimer::singleShot(0, [target]() { RKWardMainWindow::getMain()->askOpenWorkspace(target); });
+			} else if (category == RKRecentUrls::outputId()) {
+				RKWardMainWindow::getMain()->slotOpenOutput(target);
+			} else {
+				// See opening workspace, above.
+				QTimer::singleShot(0, [target]() { RKWorkplace::mainWorkplace()->openAnyUrl(target); });
+			}
+		} else if (url.host () == "actions") {  // anything else
+			QString action = url.path ();
+			if (action.startsWith ('/')) action = action.mid (1);
+			if (action == "new_data_frame") {
+				RKWardMainWindow::getMain()->slotNewDataFrame();
+			} else if (action == "rpackage_install") {
+				RKWardMainWindow::getMain()->slotFileLoadLibs();
+			} else if (action == "import_assistant") {
+				RKWardMainWindow::getMain()->importData();
+			} else {
+				RK_ASSERT(false);
+			}
 		} else {
 			if (window) window->openRKHPage (url);
 			else RKWorkplace::mainWorkplace ()->openHelpWindow (url);	// will recurse with window set, via openURL()
@@ -617,7 +664,7 @@ bool RKHTMLWindow::openURL (const QUrl &url) {
 				RK_DEBUG (APP, DL_WARNING, "Applying workaround for https://bugs.kde.org/show_bug.cgi?id=405386");
 				QFile f (url.toLocalFile ());
 				f.open (QIODevice::ReadOnly);
-				page->setHtml (f.readAll());
+				page->setHtmlWrapper(f.readAll(), url.adjusted(QUrl::RemoveFilename));
 				f.close ();
 			} else {
 				page->load (url);
@@ -759,8 +806,14 @@ void RKHTMLWindow::updateCaption (const QUrl &url) {
 
 void RKHTMLWindow::refresh () {
 	RK_TRACE (APP);
+	RK_DEBUG(APP, DL_DEBUG, "reload %s", qPrintable(url().url()));
 
-	view->reload ();
+	if (isRKWardUrl(url())) {
+		// need to re-render the page
+		openRKHPage(url());
+	} else {
+		view->reload();
+	}
 }
 
 void RKHTMLWindow::scrollToBottom () {
@@ -857,7 +910,7 @@ void RKHTMLWindow::flushOutput () {
 		RKProgressControl *status = new RKProgressControl (this, i18n ("Flushing output"), i18n ("Flushing output"), RKProgressControl::CancellableNoProgress);
 		status->addRCommand (c, true);
 		status->doNonModal (true);
-		RKGlobals::rInterface ()->issueCommand (c);
+		RInterface::issueCommand (c);
 	}
 }
 
@@ -924,7 +977,7 @@ void RKHTMLWindowPart::initActions () {
 	window->file_save_action = actionCollection()->addAction(KStandardAction::Save, window, SLOT(slotSave()));
 	window->file_save_action->setText(i18n("Save Output"));
 	window->file_save_as_action = actionCollection()->addAction(KStandardAction::SaveAs, window, SLOT(slotSaveAs()));
-	window->file_save_action->setText(i18n("Save Output As"));
+	window->file_save_as_action->setText(i18n("Save Output As"));
 
 	outputFlush = actionCollection ()->addAction ("output_flush", window, SLOT (flushOutput()));
 	outputFlush->setText (i18n ("&Clear Output"));
@@ -977,10 +1030,10 @@ void RKHTMLWindowPart::setHelpWindowSkin() {
 //////////////////////////////////////////
 //////////////////////////////////////////
 
-bool RKHelpRenderer::renderRKHelp (const QUrl &url) {
+bool RKHelpRenderer::renderRKHelp (const QUrl &url, RKHTMLWindow* container) {
 	RK_TRACE (APP);
 
-	if (url.scheme () != "rkward") {
+	if (!isRKWardUrl(url)) {
 		RK_ASSERT (false);
 		return (false);
 	}
@@ -1033,8 +1086,9 @@ bool RKHelpRenderer::renderRKHelp (const QUrl &url) {
 		element = help_xml_helper.getChildElement (help_doc_element, "title", DL_WARNING);
 		page_title = help_xml_helper.i18nElementText (element, false, DL_WARNING);
 	}
-	writeHTML ("<html><head><title>" + page_title + "</title><link rel=\"stylesheet\" type=\"text/css\" href=\"" + css_filename + "\">"
-	           "<meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"></head>\n<body><div id=\"main\">\n<h1>" + page_title + "</h1>\n");
+	writeHTML("<html><head><title>" + page_title + "</title><link rel=\"stylesheet\" type=\"text/css\" href=\"" + css_filename + "\">"
+	          "<meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"></head>\n"
+	          "<body id=\"" + help_xml_helper.getStringAttribute(help_doc_element, "pageid", "standard", DL_INFO) + "\"><div id=\"main\">\n<h1>" + page_title + "</h1>\n");
 
 	if (help_doc_element.isNull ()) {
 		RK_ASSERT (for_component);
@@ -1062,21 +1116,54 @@ bool RKHelpRenderer::renderRKHelp (const QUrl &url) {
 	if (!element.isNull ()) {
 		writeHTML (startSection ("summary", i18n ("Summary"), QString (), &anchors, &anchornames));
 		writeHTML (renderHelpFragment (element));
+		writeHTML(endSection());
 	}
 
 	element = help_xml_helper.getChildElement (help_doc_element, "usage", DL_INFO);
 	if (!element.isNull ()) {
 		writeHTML (startSection ("usage", i18n ("Usage"), QString (), &anchors, &anchornames));
 		writeHTML (renderHelpFragment (element));
+		writeHTML(endSection());
 	}
 
+	bool container_refresh_connected = false;
 	XMLChildList section_elements = help_xml_helper.getChildElements (help_doc_element, "section", DL_INFO);
 	for (XMLChildList::iterator it = section_elements.begin (); it != section_elements.end (); ++it) {
 		QString title = help_xml_helper.i18nStringAttribute (*it, "title", QString (), DL_WARNING);
 		QString shorttitle = help_xml_helper.i18nStringAttribute (*it, "shorttitle", QString (), DL_DEBUG);
 		QString id = help_xml_helper.getStringAttribute (*it, "id", QString (), DL_WARNING);
 		writeHTML (startSection (id, title, shorttitle, &anchors, &anchornames));
+		QString special = help_xml_helper.getStringAttribute(*it, "special", QString(), DL_DEBUG);
+		if (!special.isEmpty()) {
+			if (special == "recentfiles") {
+				writeHTML("<ul>\n");
+				QString category = help_xml_helper.getStringAttribute(*it, "category", QString(), DL_WARNING);
+				auto list = RKRecentUrls::allRecentUrls(category);
+				if (category == RKRecentUrls::workspaceId()) {
+					if (QFile::exists(".RData")) {
+						list.prepend(QUrl::fromLocalFile(QFileInfo(".RData").absoluteFilePath()));
+					}
+				}
+				for (int i = 0; i < list.size(); ++i) {
+					writeHTML(QString("<li>&lrm;<a href=\"rkward://open/%1/%2\" title=\"%2\">%3</a></li>\n").arg(category, list[i].url(), RKCommonFunctions::escape(list[i].url(QUrl::PreferLocalFile))));
+				}
+				writeHTML("</ul>\n");
+				writeHTML(QString("<form action=\"rkward://open/%1/\"><button type=\"submit\">%3</button></form>\n").arg(category, i18n("Choose another file")));
+				if (container && !container_refresh_connected) {
+					container_refresh_connected = true;
+					auto connection = new QMetaObject::Connection;
+					*connection = QObject::connect(RKRecentUrls::notifier(), &RKRecentUrls::recentUrlsChanged, container, [connection, container](){
+						// connection must self-destruct, as it will be re-created from refresh()
+						QObject::disconnect(*connection);
+						delete connection;
+						// also, delay the actual refresh, in case, e.g. several script files are opened at once
+						QTimer::singleShot(0, container, &RKHTMLWindow::refresh);
+					});
+				}
+			}
+		}
 		writeHTML (renderHelpFragment (*it));
+		writeHTML(endSection());
 	}
 
 	// the section "settings" is the most complicated, as the labels of the individual GUI items has to be fetched from the component description. Of course it is only meaningful for component help, and not rendered for top level help pages.
@@ -1101,6 +1188,7 @@ bool RKHelpRenderer::renderRKHelp (const QUrl &url) {
 					help_xml_helper.displayError (&(*it), "Tag not allowed, here", DL_WARNING);
 				}
 			}
+			writeHTML(endSection());
 		}
 	}
 
@@ -1109,6 +1197,7 @@ bool RKHelpRenderer::renderRKHelp (const QUrl &url) {
 	if (!element.isNull ()) {
 		writeHTML (startSection ("related", i18n ("Related functions and pages"), QString (), &anchors, &anchornames));
 		writeHTML (renderHelpFragment (element));
+		writeHTML(endSection());
 	}
 
 	// "technical" section
@@ -1116,6 +1205,7 @@ bool RKHelpRenderer::renderRKHelp (const QUrl &url) {
 	if (!element.isNull ()) {
 		writeHTML (startSection ("technical", i18n ("Technical details"), QString (), &anchors, &anchornames));
 		writeHTML (renderHelpFragment (element));
+		writeHTML(endSection());
 	}
 
 	if (for_component) {
@@ -1124,6 +1214,7 @@ bool RKHelpRenderer::renderRKHelp (const QUrl &url) {
 		if (!deps.isEmpty ()) {
 			writeHTML (startSection ("dependencies", i18n ("Dependencies"), QString (), &anchors, &anchornames));
 			writeHTML (RKComponentDependency::depsToHtml (deps));
+			writeHTML(endSection());
 		}
 	}
 
@@ -1137,6 +1228,7 @@ bool RKHelpRenderer::renderRKHelp (const QUrl &url) {
 	if (about.valid) {
 		writeHTML (startSection ("about", i18n ("About"), QString (), &anchors, &anchornames));
 		writeHTML (about.toHtml ());
+		writeHTML(endSection());
 	}
 
 	// create a navigation bar
@@ -1233,7 +1325,7 @@ QString RKHelpRenderer::prepareHelpLink (const QString &href, const QString &tex
 	} else {
 		QString ltext;
 		QUrl url (href);
-		if (url.scheme () == "rkward") {
+		if (isRKWardUrl(url)) {
 			if (url.host () == "component") {
 				RKComponentHandle *chandle = componentPathToHandle (url.path ());
 				if (chandle) ltext = chandle->getLabel ();
@@ -1261,7 +1353,7 @@ QString RKHelpRenderer::prepareHelpLink (const QString &href, const QString &tex
 QString RKHelpRenderer::componentPathToId (const QString &path) {
 	RK_TRACE (APP);
 
-	QStringList path_segments = path.split ('/', QString::SkipEmptyParts);
+	QStringList path_segments = path.split ('/', RKCompatibility::SkipEmptyParts());
 	if (path_segments.count () > 2) return 0;
 	if (path_segments.count () < 1) return 0;
 	if (path_segments.count () == 1) path_segments.push_front ("rkward");
@@ -1277,7 +1369,7 @@ RKComponentHandle *RKHelpRenderer::componentPathToHandle (const QString &path) {
 }
 
 QString RKHelpRenderer::startSection (const QString &name, const QString &title, const QString &shorttitle, QStringList *anchors, QStringList *anchor_names) {
-	QString ret = "<a name=\"" + name + "\">";
+	QString ret = "<div id=\"" + name + "\"><a name=\"" + name + "\">";
 	ret.append ("<h2>" + title + "</h2>\n");
 	anchors->append (name);
 	if (!shorttitle.isNull ()) anchor_names->append (shorttitle);
@@ -1285,6 +1377,10 @@ QString RKHelpRenderer::startSection (const QString &name, const QString &title,
 	return (ret);
 }
 
+QString RKHelpRenderer::endSection() {
+	return("</div>\n");
+}
+
 void RKHelpRenderer::writeHTML (const QString& string) {
 	RK_TRACE (APP);
 
