@@ -1,19 +1,9 @@
-/***************************************************************************
-                          rktoolwindowbar  -  description
-                             -------------------
-    begin                : Fri Oct 12 2007
-    copyright            : (C) 2007-2020 by Thomas Friedrichsmeier
-    email                : thomas.friedrichsmeier@kdemail.net
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+rktoolwindowbar - This file is part of RKWard (https://rkward.kde.org). Created: Fri Oct 12 2007
+SPDX-FileCopyrightText: 2007-2020 by Thomas Friedrichsmeier <thomas.friedrichsmeier@kdemail.net>
+SPDX-FileContributor: The RKWard Team <rkward-devel@kde.org>
+SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 /* This code is based substantially on kate's katemdi! */
 
@@ -79,7 +69,7 @@ int RKToolWindowBar::getSplitterSize () const {
 		RK_ASSERT (false);
 		return 0;
 	}
-	return (splitter->sizes ()[pos]);
+	return (splitter->sizes().at(pos));
 }
 
 void RKToolWindowBar::setSplitterSize (int new_size) {
@@ -272,7 +262,7 @@ void RKToolWindowBar::tabClicked (int id) {
 	RK_ASSERT (widget);
 
 	if (widget->isActive ()) {
-		if (!widget->isAttached ()) widget->close (false);
+		if (!widget->isAttached ()) widget->close (RKMDIWindow::NoAskSaveModified);
 		else hideWidget (widget);
 	} else {
 		widget->activate (true);
