@@ -41,7 +41,6 @@ SPDX-License-Identifier: GPL-2.0-or-later
 #include "../plugin/rkcomponentmap.h"
 #include "../dialogs/rkerrordialog.h"
 #include "../rbackend/rkrinterface.h"
-#include "../rkglobals.h"
 #include "../rkward.h"
 
 #include "../debug.h"
@@ -166,7 +165,7 @@ void RKTopLevelWindowGUI::configureToolbars () {
 void RKTopLevelWindowGUI::invokeRHelp () {
 	RK_TRACE (APP);
 
-	RKGlobals::rInterface ()->issueCommand ("help.start ()", RCommand::App);
+	RInterface::issueCommand ("help.start ()", RCommand::App);
 	RKWardMainWindow::getMain ()->topLevelWidget ()->raise ();
 }
 
